/*
**    BLASTgres -- Biosequence data management in PostgreSQL
**    http://www.blastgres.org/
**
**    Copyright (C) 2005, 2006  Ruey-Lung Hsiao,  D.S. Parker
**    (rlhsiao@cs.ucla.edu, stott@cs.ucla.edu)
**
**    UCLA Center for Computational Biology
**    635 Charles Young Drive South, Suite 225
**    Los Angeles, CA 90095-7332  USA
**
**    UCLA Computer Science Dept.
**    3532 Boelter Hall
**    Los Angeles, CA 90095-1596  USA
**
**    This program is free software; you can redistribute it and/or
**    modify it under the terms of the GNU General Public License
**    as published by the Free Software Foundation; either version 2 of
**    the License, or (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
**    See the GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public
**    License along with this program; if not, write to the
**    Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
**    Boston, MA  02110-1301  USA
*/


#ifndef ___RANGE_H
#define ___RANGE_H

#include "postgres.h"
#include "utils/array.h"
#include "utils/builtins.h"
#include "global.h"
#include "range.h"

#define NDIM 1		/* dimension of array, we only limit 1-D array */

/* macros for accessing ArrayType structure */
#define ARRPTR(x)          ( (RANGE *) ARR_DATA_PTR(x) )
#define ARRNELEMS(x)       ArrayGetNItems( ARR_NDIM(x), ARR_DIMS(x))

#define ARRISVOID(x) ( (x) ? ( ( ARR_NDIM(x) == NDIM ) ? ( ( ARRNELEMS( x ) ) ? 0 : 1 ) : ( ( ARR_NDIM(x) ) ? ( \
        ereport(ERROR, \
                        (errcode(ERRCODE_ARRAY_SUBSCRIPT_ERROR), \
                         errmsg("array must be one-dimensional, not %d dimensions", ARRNELEMS( x )))) \
        ,1) : 0 )  ) : 0 )



#define SORT(x) \
	do { \
		if (ARRNELEMS(x)>1 )\
			isort( ARRPTR(x), ARRNELEMS(x) ); \
	} while (0)

#define PREPAREARR(x) \
	do { \
		if ( ARRNELEMS(x)>1 ) \
			if ( isort( ARRPTR(x), ARRNELEMS(x) ) )\
				x = _range_unique(x); \
	} while (0)

int compASC(const void *a, const void *b);
int compDESC(const void *a, const void *b);
#define QSORT(a, direction)	\
	if (ARRNELEMS(a)>1) \
		qsort((void*) ARRPTR(a), ARRNELEMS(a), sizeof(RANGE), (direction)? compASC:compDESC)


Datum           _range_ne(PG_FUNCTION_ARGS);
Datum           _range_eq(PG_FUNCTION_ARGS);
Datum           _range_contains(PG_FUNCTION_ARGS);
Datum           _range_contained(PG_FUNCTION_ARGS);
Datum           _range_overlaps(PG_FUNCTION_ARGS);
Datum           _range_union(PG_FUNCTION_ARGS);
Datum           _range_inters(PG_FUNCTION_ARGS);
Datum rangeset(PG_FUNCTION_ARGS);
Datum rcount(PG_FUNCTION_ARGS);
Datum sort(PG_FUNCTION_ARGS);
Datum sort_asc(PG_FUNCTION_ARGS);
Datum sort_desc(PG_FUNCTION_ARGS);
Datum unique(PG_FUNCTION_ARGS);
Datum idx(PG_FUNCTION_ARGS);
Datum subarray(PG_FUNCTION_ARGS);
Datum _range_push_elem(PG_FUNCTION_ARGS);
Datum _range_push_array(PG_FUNCTION_ARGS);
Datum _range_del_elem(PG_FUNCTION_ARGS);
Datum _range_union_elem(PG_FUNCTION_ARGS);
Datum _range_subtract(PG_FUNCTION_ARGS);
Datum _range_contains_interval_any(PG_FUNCTION_ARGS);
Datum _range_contains_interval_all(PG_FUNCTION_ARGS);
Datum _range_contained_interval_any(PG_FUNCTION_ARGS);
Datum _range_contained_interval_all(PG_FUNCTION_ARGS);
Datum _range_overlaps_interval_any(PG_FUNCTION_ARGS);
Datum _range_overlaps_interval_all(PG_FUNCTION_ARGS);


/* useful function */
bool isort(RANGE *a, const int len);
ArrayType *range_to_rangeset(RANGE *r);
ArrayType *new_rangeArray(int num);
ArrayType *copy_rangeArray(ArrayType *a);
ArrayType *resize_rangeArray(ArrayType *a, int num);
ArrayType *_range_unique(ArrayType *a);
int32 _range_match_first(ArrayType *a, RANGE *b);
ArrayType *_range_add_elem(ArrayType *a, RANGE *r);
ArrayType *_range_concat(ArrayType *a, ArrayType *b);


bool _range_contains_range(ArrayType *a, RANGE *b);
bool inner_range_overlaps(ArrayType *a, ArrayType *b);
bool inner_range_contains(ArrayType *a, ArrayType *b);
ArrayType *inner_range_union(ArrayType *a, ArrayType *b);
ArrayType *inner_range_inters(ArrayType *a, ArrayType *b);
void _range_min_bounding_box(ArrayType *arr, RANGE_int *min, RANGE_int *max);
bool internal_range_contains__range( RANGE *range, ArrayType *arr );
bool internal_range_overlaps__range( RANGE *range, ArrayType *arr );


bool inner__range_contains_interval_any(ArrayType *a, RANGE *r);
bool inner__range_contains_interval_all(ArrayType *a, RANGE *r);
bool inner__range_contained_interval_any(ArrayType *a, RANGE *r);
bool inner__range_contained_interval_all(ArrayType *a, RANGE *r);
bool inner__range_overlaps_interval_any(ArrayType *a, RANGE *r);
bool inner__range_overlaps_interval_all(ArrayType *a, RANGE *r);


#endif
