/*
**    BLASTgres -- Biosequence data management in PostgreSQL
**    http://www.blastgres.org/
**
**    Copyright (C) 2005, 2006  Ruey-Lung Hsiao,  D.S. Parker
**    (rlhsiao@cs.ucla.edu, stott@cs.ucla.edu)
**
**    UCLA Center for Computational Biology
**    635 Charles Young Drive South, Suite 225
**    Los Angeles, CA 90095-7332  USA
**
**    UCLA Computer Science Dept.
**    3532 Boelter Hall
**    Los Angeles, CA 90095-1596  USA
**
**    This program is free software; you can redistribute it and/or
**    modify it under the terms of the GNU General Public License
**    as published by the Free Software Foundation; either version 2 of
**    the License, or (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
**    See the GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public
**    License along with this program; if not, write to the
**    Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
**    Boston, MA  02110-1301  USA
*/

/*-------------------------------------------------------------------------
 *
 * genbanksvc.h
 *
 *    Definitions of functions for interacting with GenBank service.
 *
 * This file is included in genbank.c and all other files which request
 * GenBank service internally.
 *
 * This is part of the BLASTgres project.
 *
 *-------------------------------------------------------------------------
 */

#ifndef GENBANKSVC_H
#define GENBANKSVC_H

#include "network.h"

#define GENBANK_RESULT_STARTTAG  "<!-- docsumok"
#define GENBANK_RESULT_ENDTAG  "<input name\"showndispmax"
#define GENBANK_QUERY_URL_PREFIX  "<a href="

#define MAX_GENBANK_DB     2

#define MAX_GENBANK_FIELD_NO    10
#define GB_FIELD_LOCUS          0
#define GB_FIELD_TYPE           1
#define GB_FIELD_DIVISION       2
#define GB_FIELD_RECORD_DATE    3
#define GB_FIELD_ACCESSION      4
#define GB_FIELD_VERSION        5
#define GB_FIELD_GENBANK_ID     6
#define GB_FIELD_SPECIES        7
#define GB_FIELD_DESCRIPTION    8
#define GB_FIELD_SEQUENCE       9

typedef struct GenbankData
{
   char *fields[MAX_GENBANK_FIELD_NO];
   int  lower, upper;
} GenbankData;

typedef GenbankData *GenbankRecordPointer;


/* exported functions */
char* genbank_entrez( char* );
GenbankRecordPointer genbank_retrieve(char *, int);

/* functions used internally */
void set_default_genbank_param( HttpContext hc );
void FreeGenbankRecord( GenbankRecordPointer );
GenbankRecordPointer GenbankParser(char *data);
#endif
