/*
**    BLASTgres -- Biosequence data management in PostgreSQL
**    http://www.blastgres.org/
**
**    Copyright (C) 2005, 2006  Ruey-Lung Hsiao,  D.S. Parker
**    (rlhsiao@cs.ucla.edu, stott@cs.ucla.edu)
**
**    UCLA Center for Computational Biology
**    635 Charles Young Drive South, Suite 225
**    Los Angeles, CA 90095-7332  USA
**
**    UCLA Computer Science Dept.
**    3532 Boelter Hall
**    Los Angeles, CA 90095-1596  USA
**
**    This program is free software; you can redistribute it and/or
**    modify it under the terms of the GNU General Public License
**    as published by the Free Software Foundation; either version 2 of
**    the License, or (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
**    See the GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public
**    License along with this program; if not, write to the
**    Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
**    Boston, MA  02110-1301  USA
*/

/*-------------------------------------------------------------------------
 *
 * loc_gist.h
 *
 *    Definitions of functions for loc gist accessmethod.
 *
 * This file is included in loc_gist.c and all other files which require
 * range datatype in Postgresql.
 *
 * This is part of the BLASTgres project.
 *
 *-------------------------------------------------------------------------
 */

#ifndef LOC_GIST_H
#define LOC_GIST_H

#include "postgres.h"
#include "range.h"
#include "loc.h"

typedef struct LOCKEY
{
  uint32 s_lower, s_upper;
  RANGE interval;
  char strand;
} LOCKEY;

#define LOCEqualStrategyNumber               1
#define LOCContainsStrategyNumber            2
#define LOCLeftStrategyNumber                3
#define LOCOverLeftStrategyNumber            4
#define LOCRightStrategyNumber               5
#define LOCOverRightStrategyNumber           6
#define LOCContainedStrategyNumber           7

PG_FUNCTION_INFO_V1(lockey_in);
PG_FUNCTION_INFO_V1(lockey_out);
Datum lockey_in(PG_FUNCTION_ARGS);
Datum lockey_out(PG_FUNCTION_ARGS);


PG_FUNCTION_INFO_V1(gloc_compress);
PG_FUNCTION_INFO_V1(gloc_decompress);
PG_FUNCTION_INFO_V1(gloc_union);
PG_FUNCTION_INFO_V1(gloc_picksplit);
PG_FUNCTION_INFO_V1(gloc_consistent);
PG_FUNCTION_INFO_V1(gloc_penalty);
PG_FUNCTION_INFO_V1(gloc_same);
PG_FUNCTION_INFO_V1(bloc_ops_cmp);

Datum gloc_compress(PG_FUNCTION_ARGS);
Datum gloc_decompress(PG_FUNCTION_ARGS);
Datum gloc_union(PG_FUNCTION_ARGS);
Datum gloc_picksplit(PG_FUNCTION_ARGS);
Datum gloc_consistent(PG_FUNCTION_ARGS);
Datum gloc_penalty(PG_FUNCTION_ARGS);
Datum gloc_same(PG_FUNCTION_ARGS);
Datum bloc_ops_cmp(PG_FUNCTION_ARGS);
// FUNCTION CLASS #4: internal helper functions (not intended to export to users)
Datum LOC_leaf_consistent( LOCKEY*, LOC*, StrategyNumber);
Datum LOC_internal_consistent(LOCKEY*, LOC*, StrategyNumber);
uint32 get_union_size(uint32 a1, uint32 a2, uint32 b1, uint32 b2);
uint32 get_inter_size(uint32 a1, uint32 a2, uint32 b1, uint32 b2);


#endif  /* LOC_GIST_H */
