/*
**    BLASTgres -- Biosequence data management in PostgreSQL
**    http://www.blastgres.org/
**
**    Copyright (C) 2005, 2006  Ruey-Lung Hsiao,  D.S. Parker
**    (rlhsiao@cs.ucla.edu, stott@cs.ucla.edu)
**
**    UCLA Center for Computational Biology
**    635 Charles Young Drive South, Suite 225
**    Los Angeles, CA 90095-7332  USA
**
**    UCLA Computer Science Dept.
**    3532 Boelter Hall
**    Los Angeles, CA 90095-1596  USA
**
**    This program is free software; you can redistribute it and/or
**    modify it under the terms of the GNU General Public License
**    as published by the Free Software Foundation; either version 2 of
**    the License, or (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
**    See the GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public
**    License along with this program; if not, write to the
**    Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
**    Boston, MA  02110-1301  USA
*/

/*-------------------------------------------------------------------------
 *
 * range.h
 *
 *    Definitions of functions for range datatype.
 *    the range datatype is defined as a pair of integer specifying an
 *    interval. end points (lower, upper) are included.
 *
 * This file is included in range.c and all other files which require
 * range datatype in Postgresql.
 *
 * This is part of the BLASTgres project.
 *
 *-------------------------------------------------------------------------
 */

#ifndef RANGE_H
#define RANGE_H

#include "global.h"

typedef struct RANGE
{
   RANGE_int lower, upper;
} RANGE;


/* input/output functions required for postgresql for user defined datatype. */
RANGE *range_in(char *);
char *range_out(RANGE* );

/* membership functions for range data type */

RANGE_int* range_lower(RANGE* );
RANGE_int* range_upper(RANGE* );
RANGE_int* range_center(RANGE* );


/* R-tree support functions */
bool range_eq(RANGE* a, RANGE* b);
bool range_contains(RANGE * a, RANGE * b);
bool range_inside(RANGE *a, RANGE *b);
bool range_contained(RANGE * a, RANGE * b);
bool range_overlaps(RANGE * a, RANGE * b);
bool range_left(RANGE * a, RANGE * b);
bool range_over_left(RANGE * a, RANGE * b);
bool range_right(RANGE * a, RANGE * b);
bool range_over_right(RANGE * a, RANGE * b);
RANGE *range_union(RANGE * a, RANGE * b);
RANGE *range_inter(RANGE * a, RANGE * b);
RANGE_int *range_size( RANGE *a);
void rt_range_size(RANGE *a, RANGE_int*sz );
bool range_contains_int(RANGE* a, RANGE_int* b);


/* Various operators */
bool range_lt(RANGE * a, RANGE * b);
bool range_le(RANGE * a, RANGE * b);
bool range_gt(RANGE * a, RANGE * b);
bool range_ge(RANGE * a, RANGE * b);
int32 range_cmp(RANGE * a, RANGE * b);
bool range_ne(RANGE * a, RANGE * b);
bool range_meets(RANGE *a, RANGE *b);
bool range_met_by(RANGE *a,RANGE *b);
bool range_starts(RANGE *a, RANGE *b);
bool range_started_by(RANGE *a, RANGE *b);
bool range_finishes(RANGE *a, RANGE *b);
bool range_finished_by(RANGE *a, RANGE *b);
RANGE* range_plus(RANGE *a, RANGE *b);
RANGE* range_minus(RANGE *a, RANGE *b);
RANGE* range_times(RANGE *a, RANGE *b);
RANGE* range_timesconst(RANGE *a, int32 b);
RANGE* range_consttimes(int32 b, RANGE*a);
RANGE* range_duplicate(RANGE* a);
void   range_copy(RANGE *a, RANGE *b);
RANGE* range_maxmin(RANGE *a, RANGE *b);
RANGE* range_minmax(RANGE *a, RANGE *b);
RANGE* range_extend(RANGE *a, int32 b);
bool range_same_lower(RANGE *a, RANGE *b);
bool range_same_upper(RANGE *a, RANGE *b);
RANGE* range_constplus(RANGE_int* a, RANGE *b);
RANGE* range_plusconst(RANGE *a, RANGE_int* b);
RANGE* range_minusconst(RANGE *a, RANGE_int* b);
RANGE* range_torange(RANGE_int* a, RANGE_int* b);
RANGE* range_constminus(RANGE_int* a, RANGE *b);


#endif
