/*
**    BLASTgres -- Biosequence data management in PostgreSQL
**    http://www.blastgres.org/
**
**    Copyright (C) 2005, 2006  Ruey-Lung Hsiao,  D.S. Parker
**    (rlhsiao@cs.ucla.edu, stott@cs.ucla.edu)
**
**    UCLA Center for Computational Biology
**    635 Charles Young Drive South, Suite 225
**    Los Angeles, CA 90095-7332  USA
**
**    UCLA Computer Science Dept.
**    3532 Boelter Hall
**    Los Angeles, CA 90095-1596  USA
**
**    This program is free software; you can redistribute it and/or
**    modify it under the terms of the GNU General Public License
**    as published by the Free Software Foundation; either version 2 of
**    the License, or (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
**    See the GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public
**    License along with this program; if not, write to the
**    Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
**    Boston, MA  02110-1301  USA
*/

/*-------------------------------------------------------------------------
 *
 * range_gist.h
 *
 *    Definitions of functions for range gist access method.
 *    the range datatype is defined as a pair of integer specifying an
 *    interval. end points (lower, upper) are included.
 *
 * This file is included in range.c and all other files which require
 * range datatype in Postgresql.
 *
 * This is part of the BLASTgres project.
 *
 *-------------------------------------------------------------------------
 */

#ifndef RANGE_GIST_H
#define RANGE_GIST_H
#include "global.h"
#include "range.h"

/* six Gist methods */
bool        grange_consistent(GISTENTRY *entry, RANGE * query, StrategyNumber strategy);
GISTENTRY  *grange_compress(GISTENTRY *entry);
GISTENTRY  *grange_decompress(GISTENTRY *entry);
RANGE_int      *grange_penalty(GISTENTRY *origentry, GISTENTRY *newentry, RANGE_int *result);

PG_FUNCTION_INFO_V1(grange_picksplit);
Datum grange_picksplit(PG_FUNCTION_ARGS);
PG_FUNCTION_INFO_V1(grange_union);
Datum  grange_union(PG_FUNCTION_ARGS);
bool       *grange_same(RANGE* b1, RANGE* b2, bool *result);

/* auxilliary functions for GiST implementation */
bool        grange_leaf_consistent(RANGE * key, RANGE * query, StrategyNumber strategy);
bool        grange_internal_consistent(RANGE * key, RANGE * query, StrategyNumber strategy);
RANGE      *grange_binary_union(RANGE * r1, RANGE* r2, int *sizep);

#define GiSTRangeSameLowerStrategyNumber 10
#define GiSTRangeSameUpperStrategyNumber 11
#endif
