/*
**    BLASTgres -- Biosequence data management in PostgreSQL
**    http://www.blastgres.org/
**
**    Copyright (C) 2005, 2006  Ruey-Lung Hsiao,  D.S. Parker
**    (rlhsiao@cs.ucla.edu, stott@cs.ucla.edu)
**
**    UCLA Center for Computational Biology
**    635 Charles Young Drive South, Suite 225
**    Los Angeles, CA 90095-7332  USA
**
**    UCLA Computer Science Dept.
**    3532 Boelter Hall
**    Los Angeles, CA 90095-1596  USA
**
**    This program is free software; you can redistribute it and/or
**    modify it under the terms of the GNU General Public License
**    as published by the Free Software Foundation; either version 2 of
**    the License, or (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
**    See the GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public
**    License along with this program; if not, write to the
**    Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
**    Boston, MA  02110-1301  USA
*/

%{
#define YYPARSE_PARAM result  /* need this to pass a pointer (void *) to yyparse */
  
#include "postgres.h"

#include <math.h>
#include <string.h>

#include "fmgr.h"
#include "utils/builtins.h"
#include "segdata.h"

#undef yylex                  /* failure to redefine yylex will result in calling the */
#define yylex seg_yylex       /* wrong scanner when running inside postgres backend  */

  extern int yylex(void);     /* defined as seg_yylex in segscan.l */
  void seg_yyerror(const char *message);
  int seg_yyparse( void *result );
 
  char idbuffer[1024];  
  int64 tmp;
%}

/* BISON Declarations */
%union {
  struct BND {
    int64 lower, upper;
    char strand;
  } bnd;
  char *text;
}

%token <text> ID 
%token <text> DIGITS
%token <text> LEFT
%token <text> RIGHT
%token <text> LEFT_P
%token <text> RIGHT_P
%token <text> NEG
%token <text> DOTDOT
%type <text> identifier
%type <bnd> range_list
%type <bnd> range_item
%type <bnd> range
%start spec

/* Grammar follows */
%%

spec:	identifier  range_list {
	   ((SEG *)result)->lower = $2.lower;
	   ((SEG *)result)->upper = $2.upper;
	   ((SEG *)result)->strand = $2.strand;
	   strcpy( ((SEG *)result)->id, idbuffer);
	}
	;
identifier:	ID {
			strcpy($$,$1);
		        strcpy(idbuffer,$1);
		}
		;
range_list:	range_list range_item  {
                  if ( ($2.lower-1+$1.lower)>$1.upper )
                   {
                      ereport(ERROR, 
                               (errcode(ERRCODE_INVALID_PARAMETER_VALUE),
                                errmsg("boundary out of bound: %Ld exceeds the upper bound", $2.lower)));

                      YYERROR;
                   }
                  if ( ($2.upper-1+$1.lower)>$1.upper )
                   {
                      ereport(ERROR, 
                               (errcode(ERRCODE_INVALID_PARAMETER_VALUE),
                               errmsg("boundary out of bound: %Ld exceeds the upper bound", $2.upper)));

                      YYERROR;
                   }
		   $$.lower = $2.lower-1+$1.lower;
                   $$.upper = $2.upper-1+$1.lower;
                   $$.strand = $1.strand;
		   if ( $2.strand==1 )   $$.strand = 1 - $$.strand;
		}
		| range_item {
                  $$.lower = $1.lower;
                  $$.upper = $1.upper;
                  $$.strand = $1.strand;		  
		}
		;
range_item:     LEFT_P range_list RIGHT_P NEG {
                  $$.lower = $2.lower;
                  $$.upper = $2.upper;
                  $$.strand = 1 - $2.strand;
                }
                | LEFT_P range_list RIGHT_P {
                  $$.lower = $2.lower;
	          $$.upper = $2.upper;
                  $$.strand = $2.strand;
                }
                | range NEG {
                  $$.lower = $1.lower;
                  $$.upper = $1.upper;
                  $$.strand = 1- $1.strand;
                };
                | range {
                   $$.lower = $1.lower;
		   $$.upper = $1.upper;
                   $$.strand = $1.strand;
                }
                ;
range:  LEFT DIGITS DOTDOT DIGITS RIGHT          {
          $$.lower = (int64) atoi($2);
          $$.upper = (int64) atoi($4);
	  $$.strand = 0;
          if ( $$.lower > $$.upper )
          {
             tmp = $$.upper;             
             $$.upper = $$.lower;
             $$.strand = 1 - $$.strand;
             /*
             ereport(ERROR, 
                      (errcode(ERRCODE_INVALID_PARAMETER_VALUE),
                      errmsg("swapped boundaries: %Ld is greater than %Ld", $$.lower, $$.upper)));
             YYERROR;
             */
          }
        }
        ;
%%

#include "segscan.c"
