/*
**    BLASTgres -- Biosequence data management in PostgreSQL
**    http://www.blastgres.org/
**
**    Copyright (C) 2005, 2006  Ruey-Lung Hsiao,  D.S. Parker
**    (rlhsiao@cs.ucla.edu, stott@cs.ucla.edu)
**
**    UCLA Center for Computational Biology
**    635 Charles Young Drive South, Suite 225
**    Los Angeles, CA 90095-7332  USA
**
**    UCLA Computer Science Dept.
**    3532 Boelter Hall
**    Los Angeles, CA 90095-1596  USA
**
**    This program is free software; you can redistribute it and/or
**    modify it under the terms of the GNU General Public License
**    as published by the Free Software Foundation; either version 2 of
**    the License, or (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
**    See the GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public
**    License along with this program; if not, write to the
**    Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
**    Boston, MA  02110-1301  USA
*/

%{

#include "postgres.h"

#define YY_READ_BUF_SIZE 16777216

#define fprintf(file, fmt, msg)  ereport(ERROR, (errmsg_internal("%s", msg)))

static YY_BUFFER_STATE scanbufhandle;
static char *scanbuf;
static int	scanbuflen;

int seg_yylex(void);

void seg_scanner_init(const char *str);
void seg_scanner_finish(void);
%}

%option 8bit
%option never-interactive
%option nodefault
%option nounput
%option noyywrap
%option prefix="seg_yy"

LETTER	     [A-Za-z]
DIGIT	     [0-9]
ID	     ([A-Za-z]|[0-9][\_])[A-Za-z0-9\_\-\|:\.]*
DIGITS	     {DIGIT}+

%%

{ID}	     { yylval.text = yytext; return ID; }
{DIGITS}     { yylval.text = yytext; return DIGITS; }
"["     {
        return LEFT;
        }
"]"     {
        return RIGHT;
        }
".."|":"    {
        return DOTDOT;
        }
"("     {
        return LEFT_P;
        }
")"     {
        return RIGHT_P;
        }
"~"     {
        return NEG;
	}
[ \t\n\r\f]+ {  /* discard spaces */}
.          {  return yytext[0]; /* alert parser of the garbage */ }

%%

void yyerror(const char *message)
{
  if (*yytext == YY_END_OF_BUFFER_CHAR)
  {
    ereport(ERROR,
   	    (errcode(ERRCODE_SYNTAX_ERROR),
	     errmsg("bad seg representation"),
	      /* translator: %s is typically "syntax error" */
	     errdetail("%s at end of input", message)));
  }
  else
  {
    ereport(ERROR,
            (errcode(ERRCODE_SYNTAX_ERROR),
	     errmsg("bad seg representation"),
	     /* translator: first %s is typically "syntax error" */
	     errdetail("%s at or near \"%s\"", message, yytext)));
    }
}


/* called prior to parsing */
void seg_scanner_init(const char *str)
{
  Size	slen = strlen(str);

	if (YY_CURRENT_BUFFER)
		yy_delete_buffer(YY_CURRENT_BUFFER);

	/* called during parsing */
	scanbuflen = slen;
	scanbuf = palloc(slen + 2);
	memcpy(scanbuf, str, slen);
	scanbuf[slen] = scanbuf[slen + 1] = YY_END_OF_BUFFER_CHAR;
	scanbufhandle = yy_scan_buffer(scanbuf, slen + 2);

	BEGIN(INITIAL);
}


/* called after parsing */
void
seg_scanner_finish(void)
{
	yy_delete_buffer(scanbufhandle);
	pfree(scanbuf);
}
