\set ECHO none
\i BLASTgres.sql
\set ECHO all

--------------------------------------------------------------------------
-- demo: Alignment Tables & Alternative Splicing queries
-- PostgreSQL/BLASTgres implementation by Stott Parker, 1/2005.
--------------------------------------------------------------------------

-- entities:
--
-- 	gene
-- 	splice
-- 	exon
-- 	mrna
-- 	isoform
-- 	protein
-- 	protein_feature
--
-- alignment tables:
--
-- 	gene_ortholog
-- 	exon_exon
-- 	isoform_exon
--
-- sequence tables:
--
--	protein_sequence
--	mrna_sequence
--	genomic_sequence
--

--------------------------------------------------------------------------

drop table gene ;
drop table gene_ortholog ;
drop table splice;
drop table exon;
drop table mrna;
drop table protein;
drop table isoform ;
drop table exon_exon ;
drop table isoform_exon ;
drop table protein_feature ;
drop table protein_sequence ;
drop table mrna_sequence ;
drop table genomic_sequence ;

drop table exon_feature ;
drop table isoform_shared_exon ;
drop table unique_isoform_exon ;
drop table number_of_isoform_shared_exons ;
drop table isoform_exon_sharing ;

drop table splice_exon_overlap ;
drop table alternative_splicing ;
drop table exon_feature_removing_splice ;
drop table alternatively_spliced_genes ;
drop table nonconserved_alternative_splicing ;

drop table genes_with_multiple_orthologs ;
drop table orthologous_gene_protein_feature_differences ;
drop table pairwise_orthologous_gene_protein_feature_differences ;

drop table alternatively_spliced_exon ;
drop table stopless_peptide_exon ;
drop table peptide_exon ;
drop table stopless_peptide_alternatively_spliced_exon ;

drop table splice_site ;


--------------------------------------------------------------------------
-- currently sequence identifiers are represented by 'varchar(32)' everywhere.
--------------------------------------------------------------------------



CREATE TABLE gene (
	gene         varchar(32),
	organism     varchar(32),
	chromosome   varchar(4),
	mrna_id      varchar(32),
	protein_id   varchar(32),
	cluster_id   varchar(32),
        genomic      loc
);

INSERT INTO gene VALUES ( 'HLA-DMB', 'Homo sapiens',  '6', 'NM_002118.3', 'P28068', 'Hs.1162',   'NT_007592.7[7813399..7823803]~' );
INSERT INTO gene VALUES ( 'H2-DMb1', 'Mus musculus', '17', 'NM_010387.1', 'P35737', 'Mm.195060', 'NT_039662.1[402109..409147]'    );
INSERT INTO gene VALUES ( 'H2-DMb2', 'Mus musculus', '17', 'NM_010388.2', 'P35737', 'Mm.195060', 'NT_039662.1[394134..400213]'    );



CREATE TABLE gene_ortholog (
	gene        varchar(32),
	ortholog    varchar(32)
);

INSERT INTO gene_ortholog VALUES ( 'HLA-DMB', 'H2-DMb1' );
INSERT INTO gene_ortholog VALUES ( 'HLA-DMB', 'H2-DMb2' );



CREATE TABLE splice (
        gene              varchar(32),
        splice_no         int,
        genomic_interval  range,
        length            int,
        _5prime_site      char(20),
        _3prime_site      char(20)
);

INSERT INTO splice VALUES ( 'HLA-DMB', 1, '2289..4075', 1787, 'ACAGGAGCAGgtaaggacac', 'gctcctctagGTGGCTTCGT' );
INSERT INTO splice VALUES ( 'HLA-DMB', 2, '4358..5584', 1227, 'AACAGGACACgtgaggagag', 'tcctatgcagGGCCACCATC' );
INSERT INTO splice VALUES ( 'HLA-DMB', 3, '5870..7388', 1519, 'CGGGACTGGAgtaagtgtat', 'ttttttgcagCACCTGGGCT' );
INSERT INTO splice VALUES ( 'HLA-DMB', 4, '5870..7663', 1794, 'CGGGACTGGAgtaagtgtat', 'cctctcttagGTTACACTCC' );
INSERT INTO splice VALUES ( 'HLA-DMB', 5, '7506..8053',  548, 'GGCCACTCTAgtgagtgact', 'tattctgtagGATGGCACAT' );
INSERT INTO splice VALUES ( 'HLA-DMB', 6, '7506..7663',  158, 'GGCCACTCTAgtgagtgact', 'cctctcttagGTTACACTCC' );
INSERT INTO splice VALUES ( 'HLA-DMB', 7, '7664..8053',  390, 'CCTCTCTTAGgttacactcc', 'tattctgtagGATGGCACAT' );
INSERT INTO splice VALUES ( 'HLA-DMB', 8, '7700..8053',  354, 'TATTCAGAAGgtaacatctc', 'tattctgtagGATGGCACAT' );

INSERT INTO splice VALUES ( 'H2-DMb1', 1, '264..2242',  1979, 'ATGGGGGCAGgtaaggtaac', 'cttcccccagGTGGCTTTGT' );
INSERT INTO splice VALUES ( 'H2-DMb1', 2, '2525..4055', 1531, 'CACAGAACGAgtgagcagag', 'tcccatgcagGAGCGCCATC' );
INSERT INTO splice VALUES ( 'H2-DMb1', 3, '4341..6153', 1813, 'GGGGACTGGAgtaagtgtgt', 'tactttgtagCACCTGGGCT' );
INSERT INTO splice VALUES ( 'H2-DMb1', 4, '6271..6438',  168, 'CATTCCTCCAgtgagtgatc', 'cctcttctagGCTACACTCC' );
INSERT INTO splice VALUES ( 'H2-DMb1', 5, '6475..6738',  264, 'TACCCGGAAGgtaacatttg', 'gcttctgcagGACAGCATTA' );

INSERT INTO splice VALUES ( 'H2-DMb2', 1, '256..1680',  1425, 'ATGGGGGCAGgtaagataac', 'taacatccagCCACATCTCT' );
INSERT INTO splice VALUES ( 'H2-DMb2', 2, '1779..2435',  657, 'CCCCCAAAAGgtaggtgtgc', 'cttcccccagGTGGCTTTGT' );
INSERT INTO splice VALUES ( 'H2-DMb2', 3, '256..2435',  2180, 'ATGGGGGCAGgtaagataac', 'cttcccccagGTGGCTTTGT' );
INSERT INTO splice VALUES ( 'H2-DMb2', 4, '2718..3335',  618, 'CACAGAACGAgtgagcagag', 'tcccatgcagGAGCGCCATC' );
INSERT INTO splice VALUES ( 'H2-DMb2', 5, '3621..5290', 1670, 'GGGGACTGGAgtaagtgtgt', 'tactttgtagCACCTGGGCT' );
INSERT INTO splice VALUES ( 'H2-DMb2', 6, '5408..5574',  167, 'CATTCCTCCAgtgagtgatc', 'cttcttctagGCTACACTCC' );
INSERT INTO splice VALUES ( 'H2-DMb2', 7, '5611..5869',  259, 'TACCCAGAAGgtaacatttg', 'gcttctgcagGACGGCACTA' );

-- -- these first two splices for H2-DMb2 are obtained from BC052864.1.
-- -- However the corresponding exon yields nonsense protein (see below)




CREATE TABLE exon (
       gene              varchar(32),
       exon_no           int,
       genomic_interval  range,
       coding_interval   range,
       coding_length     int,
       coding_mrna       loc
);

INSERT INTO exon VALUES ( 'HLA-DMB', 1, '1264..2288', '2234..2288',   55, 'NM_002118.3[234..288]'   );
INSERT INTO exon VALUES ( 'HLA-DMB', 2, '4076..4357', '4076..4357',  282, 'NM_002118.3[289..570]'   );
INSERT INTO exon VALUES ( 'HLA-DMB', 3, '5585..5869', '5585..5869',  285, 'NM_002118.3[571..855]'   );
INSERT INTO exon VALUES ( 'HLA-DMB', 4, '7389..7505', '7389..7505',  117, 'NM_002118.3[856..972]'   );
INSERT INTO exon VALUES ( 'HLA-DMB', 5, '7664..7699', '7664..7699',   36, 'NM_002118.3[973..1008]'  );
INSERT INTO exon VALUES ( 'HLA-DMB', 6, '8054..8412', '8054..8070',   17, 'NM_002118.3[1009..1025]' );

INSERT INTO exon VALUES ( 'H2-DMb1', 1, '1..263',     '209..263',     55, 'NM_010387.2[210..264]'   );
INSERT INTO exon VALUES ( 'H2-DMb1', 2, '2243..2524', '2243..2524',  282, 'NM_010387.2[265..546]'   );
INSERT INTO exon VALUES ( 'H2-DMb1', 3, '4056..4340', '4056..4340',  285, 'NM_010387.2[547..831]'   );
INSERT INTO exon VALUES ( 'H2-DMb1', 4, '6154..6270', '6154..6270',  117, 'NM_010387.2[832..948]'   );
INSERT INTO exon VALUES ( 'H2-DMb1', 5, '6439..6474', '6439..6474',   36, 'NM_010387.2[949..984]'   );
INSERT INTO exon VALUES ( 'H2-DMb1', 6, '6739..7039', '6739..6749',   11, 'NM_010387.2[985..995]'   );

INSERT INTO exon VALUES ( 'H2-DMb2', 1, '56..255',    '56..255',     200, 'BC052864.1[158..212]'    );
INSERT INTO exon VALUES ( 'H2-DMb2', 2, '1681..1778', '1681..1778',   98, 'BC052864.1[213..229]'    );
INSERT INTO exon VALUES ( 'H2-DMb2', 3, '201..255',   '201..255',     55, 'NM_010388.1[1..55]'      );
INSERT INTO exon VALUES ( 'H2-DMb2', 4, '2436..2717', '2436..2717',  282, 'NM_010388.1[56..337]'    );
INSERT INTO exon VALUES ( 'H2-DMb2', 5, '3336..3620', '3336..3620',  285, 'NM_010388.1[338..622]'   );
INSERT INTO exon VALUES ( 'H2-DMb2', 6, '5291..5407', '5291..5407',  117, 'NM_010388.1[623..739]'   );
INSERT INTO exon VALUES ( 'H2-DMb2', 7, '5575..5610', '5575..5610',   36, 'NM_010388.1[740..775]'   );
INSERT INTO exon VALUES ( 'H2-DMb2', 8, '5870..5880', '5870..5880',   11, 'NM_010388.1[776..786]'   );

-- -- ASD and other sites list exon 2 as a new exon:
-- -- http://www.ebi.ac.uk/asd-srv/Index.cgi?ensembl_id=ENSMUSG00000037548&method=ENSEMBL&specie=M&product=SINGLE
-- -- Its initial segment generates nonsense protein:
-- --    instead of the 261-AA sequence below,
-- --    it yields MAALWLLLLVLSLHCMGAATSLTP<stop>,
-- --    hitting a stop codon 6AA after entering this "new exon".
-- -- However, BC052864[649..1041] also generates a protein sequence
-- --    of length 131 (393 nt).  It is the second half of H2-DMb2.



CREATE TABLE mrna (
       gene              varchar(32),
       coding_mrna       loc,
       coding_length     int
);

INSERT INTO mrna VALUES ( 'HLA-DMB', 'NM_002118.3[234..1025]', 792 );
INSERT INTO mrna VALUES ( 'H2-DMb1', 'NM_010387.2[210..995]',  786 );
INSERT INTO mrna VALUES ( 'H2-DMb2', 'NM_010388.1[1..786]',    786 );



CREATE TABLE protein (
       gene              varchar(32),
       protein_id        varchar(32),
       coding_length     int
);


INSERT INTO protein VALUES ( 'HLA-DMB', 'P28068', 263 );
INSERT INTO protein VALUES ( 'H2-DMb1', 'P35737', 261 );
INSERT INTO protein VALUES ( 'H2-DMb2', 'P35737', 261 );



CREATE TABLE isoform (
       isoform_id       varchar(32),
       isoform_no       int,
       gene             varchar(32),
       cluster_id       varchar(32),
       coding_mrna       loc,
       coding_length     int
);

INSERT INTO isoform VALUES ( 'ASAP_55845',  1, 'HLA-DMB', 'Hs.1162', 'ASAP_55845[971..1762]', 792 );
INSERT INTO isoform VALUES ( 'ASAP_55846',  2, 'HLA-DMB', 'Hs.1162', 'ASAP_55846[971..1609]', 639 );
INSERT INTO isoform VALUES ( 'ASAP_55847',  3, 'HLA-DMB', 'Hs.1162', 'ASAP_55847[971..1726]', 756 );
INSERT INTO isoform VALUES ( 'ASAP_55848',  4, 'HLA-DMB', 'Hs.1162', 'ASAP_55848[971..1645]', 675 );
INSERT INTO isoform VALUES ( 'NM_010388.1', 1, 'H2-DMb2', 'Hs.1162', 'NM_010388.1[1..786]',   786 );
INSERT INTO isoform VALUES ( 'BC052864.1',  2, 'H2-DMb2', 'Hs.1162', 'BC052864.1[158..229]',   24 );



CREATE TABLE exon_exon (
        gene1                   varchar(32),
        exon_no1                int,
        gene2                   varchar(32),
        exon_no2                int,
        coding_ungapped_Escore  float,
        coding_percent_align    float
);

INSERT INTO exon_exon VALUES ( 'HLA-DMB', 1, 'H2-DMb1', 1, 1e-07, 0.70 );
INSERT INTO exon_exon VALUES ( 'HLA-DMB', 2, 'H2-DMb1', 2, 5e-52, 0.77 );
INSERT INTO exon_exon VALUES ( 'HLA-DMB', 3, 'H2-DMb1', 3, 3e-59, 0.81 );
INSERT INTO exon_exon VALUES ( 'HLA-DMB', 4, 'H2-DMb1', 4, 1e-21, 0.78 );
INSERT INTO exon_exon VALUES ( 'HLA-DMB', 5, 'H2-DMb1', 5, 9e-03, 1.00 );

INSERT INTO exon_exon VALUES ( 'HLA-DMB', 1, 'H2-DMb2', 3, 3e-07, 0.69 );
INSERT INTO exon_exon VALUES ( 'HLA-DMB', 2, 'H2-DMb2', 4, 5e-53, 0.77 );
INSERT INTO exon_exon VALUES ( 'HLA-DMB', 3, 'H2-DMb2', 5, 3e-59, 0.81 );
INSERT INTO exon_exon VALUES ( 'HLA-DMB', 4, 'H2-DMb2', 6, 1e-21, 0.78 );
INSERT INTO exon_exon VALUES ( 'HLA-DMB', 5, 'H2-DMb2', 7, 9e-03, 1.00 );

INSERT INTO exon_exon VALUES ( 'H2-DMb1', 1, 'H2-DMb2', 3, 4e-15, 0.98 );
INSERT INTO exon_exon VALUES ( 'H2-DMb1', 2, 'H2-DMb2', 4, 1e-72, 0.91 );
INSERT INTO exon_exon VALUES ( 'H2-DMb1', 3, 'H2-DMb2', 5, 1e-84, 0.99 );
INSERT INTO exon_exon VALUES ( 'H2-DMb1', 4, 'H2-DMb2', 6, 4e-34, 1.00 );
INSERT INTO exon_exon VALUES ( 'H2-DMb1', 5, 'H2-DMb2', 7, 6e-13, 0.94 );



CREATE TABLE isoform_exon (
        isoform_id    varchar(32),
        location      loc,
        gene          varchar(32),
        exon_no       int
);

INSERT INTO isoform_exon VALUES ( 'ASAP_55845', 'ASAP_55845[1..1025]',    'HLA-DMB', 1 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55845', 'ASAP_55845[1026..1307]', 'HLA-DMB', 2 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55845', 'ASAP_55845[1308..1592]', 'HLA-DMB', 3 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55845', 'ASAP_55845[1593..1709]', 'HLA-DMB', 4 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55845', 'ASAP_55845[1710..1745]', 'HLA-DMB', 5 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55845', 'ASAP_55845[1746..2104]', 'HLA-DMB', 6 );

INSERT INTO isoform_exon VALUES ( 'ASAP_55846', 'ASAP_55846[1..1025]',    'HLA-DMB', 1 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55846', 'ASAP_55846[1026..1307]', 'HLA-DMB', 2 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55846', 'ASAP_55846[1308..1592]', 'HLA-DMB', 3 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55846', 'ASAP_55846[1593..1951]', 'HLA-DMB', 6 );

INSERT INTO isoform_exon VALUES ( 'ASAP_55847', 'ASAP_55847[1..1025]',    'HLA-DMB', 1 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55847', 'ASAP_55847[1026..1307]', 'HLA-DMB', 2 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55847', 'ASAP_55847[1308..1592]', 'HLA-DMB', 3 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55847', 'ASAP_55847[1593..1709]', 'HLA-DMB', 4 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55847', 'ASAP_55847[1710..2068]', 'HLA-DMB', 6 );

INSERT INTO isoform_exon VALUES ( 'ASAP_55848', 'ASAP_55848[1..1025]',    'HLA-DMB', 1 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55848', 'ASAP_55848[1026..1307]', 'HLA-DMB', 2 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55848', 'ASAP_55848[1308..1592]', 'HLA-DMB', 3 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55848', 'ASAP_55848[1593..1628]', 'HLA-DMB', 5 );
INSERT INTO isoform_exon VALUES ( 'ASAP_55848', 'ASAP_55848[1629..1987]', 'HLA-DMB', 6 );

INSERT INTO isoform_exon VALUES ( 'NM_010388.1', 'NM_010388.1[1..55]',    'H2-DMb2', 3 );
INSERT INTO isoform_exon VALUES ( 'NM_010388.1', 'NM_010388.1[56..337]',  'H2-DMb2', 4 );
INSERT INTO isoform_exon VALUES ( 'NM_010388.1', 'NM_010388.1[338..622]', 'H2-DMb2', 5 );
INSERT INTO isoform_exon VALUES ( 'NM_010388.1', 'NM_010388.1[623..739]', 'H2-DMb2', 6 );
INSERT INTO isoform_exon VALUES ( 'NM_010388.1', 'NM_010388.1[740..775]', 'H2-DMb2', 7 );
INSERT INTO isoform_exon VALUES ( 'NM_010388.1', 'NM_010388.1[776..786]', 'H2-DMb2', 8 );

INSERT INTO isoform_exon VALUES ( 'BC052864.1', 'BC0562864.1[13..212]',   'H2-DMb2', 1 );
INSERT INTO isoform_exon VALUES ( 'BC052864.1', 'BC0562864.1[213..310]',  'H2-DMb2', 2 );
INSERT INTO isoform_exon VALUES ( 'BC052864.1', 'BC0562864.1[311..592]',  'H2-DMb2', 4 );
INSERT INTO isoform_exon VALUES ( 'BC052864.1', 'BC0562864.1[593..877]',  'H2-DMb2', 5 );
INSERT INTO isoform_exon VALUES ( 'BC052864.1', 'BC0562864.1[878..994]',  'H2-DMb2', 6 );
INSERT INTO isoform_exon VALUES ( 'BC052864.1', 'BC0562864.1[995..1030]', 'H2-DMb2', 7 );
INSERT INTO isoform_exon VALUES ( 'BC052864.1', 'BC0562864.1[1031..1041]','H2-DMb2', 8 );



CREATE TABLE protein_feature (
        protein_id   varchar(32),
        interval     range,
        length       int,
        type         varchar(16),
        description  varchar(128)
);

INSERT INTO protein_feature VALUES ( 'P28068', '1..18',    18, 'signal',        'potential'             );
INSERT INTO protein_feature VALUES ( 'P28068', '19..112',  94, 'domain',        'lumenal beta-1'        );
INSERT INTO protein_feature VALUES ( 'P28068', '110..110',  1, 'glycosylation', 'N-linked (GlcNAc...)'  );
INSERT INTO protein_feature VALUES ( 'P28068', '113..207', 95, 'domain',        'lumenal beta-2'        );
INSERT INTO protein_feature VALUES ( 'P28068', '114..208', 95, 'domain',        'Ig-like'               );
INSERT INTO protein_feature VALUES ( 'P28068', '208..218', 11, 'domain',        'connecting peptide'    );
INSERT INTO protein_feature VALUES ( 'P28068', '219..239', 21, 'transmembrane', 'potential'             );
INSERT INTO protein_feature VALUES ( 'P28068', '240..263', 24, 'domain',        'cytoplasmic'           );
INSERT INTO protein_feature VALUES ( 'P28068', '248..251',  4, 'site',          'YXXZ motif'            );

INSERT INTO protein_feature VALUES ( 'P35737', '1..18',    18, 'signal',        'potential'             );
INSERT INTO protein_feature VALUES ( 'P35737', '19..112',  94, 'domain',        'lumenal beta-1'        );
INSERT INTO protein_feature VALUES ( 'P35737', '75..75',    1, 'glycosylation', 'N-linked (GlcNAc...)'  );
INSERT INTO protein_feature VALUES ( 'P35737', '113..207', 95, 'domain',        'lumenal beta-2'        );
INSERT INTO protein_feature VALUES ( 'P35737', '114..204', 91, 'domain',        'Ig-like'               );
INSERT INTO protein_feature VALUES ( 'P35737', '208..218', 11, 'domain',        'connecting peptide'    );
INSERT INTO protein_feature VALUES ( 'P35737', '219..239', 21, 'transmembrane', 'potential'             );
INSERT INTO protein_feature VALUES ( 'P35737', '240..261', 22, 'domain',        'cytoplasmic'           );
INSERT INTO protein_feature VALUES ( 'P35737', '248..251',  4, 'site',          'YXXZ motif'            );



CREATE TABLE protein_sequence (
        protein_id   varchar(32),
        length       int,
        seq          text
);

INSERT INTO protein_sequence VALUES ( 'P28068', 263,
   'MITFLPLLLGLSLGCTGAGGFVAHVESTCLLDDAGTPKDFTYCISFNKDLLTCWDPEENK'
   'MAPCEFGVLNSLANVLSQHLNQKDTLMQRLRNGLQNCATHTQPFWGSLTNRTRPPSVQVA'
   'KTTPFNTREPVMLACYVWGFYPAEVTITWRKNGKLVMPHSSAHKTAQPNGDWTYQTLSHL'
   'ALTPSYGDTYTCVVEHIGAPEPILRDWTPGLSPMQTLKVSVSAVTLGLGLIIFSLGVISW'
   'RRAGHSSYTPLPGSNYSEGWHIS'
);
INSERT INTO protein_sequence VALUES ( 'P35737', 261,
   'MAALWLLLLVLSLHCMGAGGFVAHVESTCVLDDAGTPQDFTYCVSFNKDLLACWDPIVGK'
   'IVPCEFGVLYPLAENFSRILNKEESLLQRLQNGLPDCASHTQPFWNALTHRTRPPSVRVA'
   'QTTPFNTREPVMLACYVWGFYPADVTITWMKNGQLVPSHSNKEKTAQPNGDWTYQTVSYL'
   'ALTPSYGDVYTCVVQHSGTSEPIRGDWTPGLSPIQTVKVSVSAATLGLGFIIFCVGFFRW'
   'RKSHSSSYTPLSGSTYPEGRH'
);
INSERT INTO protein_sequence VALUES ( 'NM_010387.2', 261,
   'MAALWLLLLVLSLDCMGAGGFVAHVESTCVLDDAGTPQDFTYCVSFNKDLLACWDPDVGK'
   'IVPCEFGVLYPWAENFSRILNKEESLLQRLQNGLLDCASHTQPFWNALTHRTRAPSVRVA'
   'QTTPFNTREPVMLACYVWGFYPADVTITWMKNGQLVPSHSNKEKTAQPNGDWTYQTVSYL'
   'ALTPSYGDVYTCVVQHSGTSEPIRGDWTPGLSPIQTVKVSVSAATLGLGFIIFCVGFFRW'
   'RKSHSSSYTPLSGSTYPEGQH'
);
INSERT INTO protein_sequence VALUES ( 'NM_010388.1', 261,
   'MAALWLLLLVLSLHCMGAGGFVAHVESTCVLNDAGTPQDFTYCVSFNKDLLACWDPDVGK'
   'IVPCEFGVLSRLAEIISNILNEQESLIHRLQNGLQDCATHTQPFWDVLTHRTRAPSVRVA'
   'QTTPFNTREPVMLACYVWGFYPADVTITWMKNGQLVPSHSNKEKTAQPNGDWTYQTVSYL'
   'ALTPSYGDVYTCVVQHSGTSEPIRGDWTPGLSPIQTVKVSVSAATLGLGFIIFCVGFFRW'
   'RKSHSSSYTPLPGSTYPEGRH'
);
INSERT INTO protein_sequence VALUES ( 'BC05624.1', 24,
   'MAALWLLLLVLSLHCMGAATSLTP'
);
INSERT INTO protein_sequence VALUES ( 'ASAP_55845', 263,
   'MITFLPLLLGLSLGCTGAGGFVAHVESTCLLDDAGTPKDFTYCISFNKDLLTCWDPEENK'
   'MAPCEFGVLNSLANVLSQHLNQKDTLMQRLRNGLQNCATHTQPFWGSLTNRTRPPSVQVA'
   'KTTPFNTREPVMLACYVWGFYPAEVTITWRKNGKLVMPHSSAHKTAQPNGDWTYQTLSHL'
   'ALTPSYGDTYTCVVEHIGAPEPILRDWTPGLSPMQTLKVSVSAVTLGLGLIIFSLGVISW'
   'RRAGHSSYTPLPGSNYSEGWHIS'
);
INSERT INTO protein_sequence VALUES ( 'ASAP_55846', 212,
   'MITFLPLLLGLSLGCTGAGGFVAHVESTCLLDDAGTPKDFTYCISFNKDLLTCWDPEENK'
   'MAPCEFGVLNSLANVLSQHLNQKDTLMQRLRNGLQNCATHTQPFWGSLTNRTRPPSVQVA'
   'KTTPFNTREPVMLACYVWGFYPAEVTITWRKNGKLVMPHSSAHKTAQPNGDWTYQTLSHL'
   'ALTPSYGDTYTCVVEHIGAPEPILRDWRWHIS'
);
INSERT INTO protein_sequence VALUES ( 'ASAP_55847', 251,
   'MITFLPLLLGLSLGCTGAGGFVAHVESTCLLDDAGTPKDFTYCISFNKDLLTCWDPEENK'
   'MAPCEFGVLNSLANVLSQHLNQKDTLMQRLRNGLQNCATHTQPFWGSLTNRTRPPSVQVA'
   'KTTPFNTREPVMLACYVWGFYPAEVTITWRKNGKLVMPHSSAHKTAQPNGDWTYQTLSHL'
   'ALTPSYGDTYTCVVEHIGAPEPILRDWTPGLSPMQTLKVSVSAVTLGLGLIIFSLGVISW'
   'RRAGHSRWHIS'
);
INSERT INTO protein_sequence VALUES ( 'ASAP_55848', 224,
   'MITFLPLLLGLSLGCTGAGGFVAHVESTCLLDDAGTPKDFTYCISFNKDLLTCWDPEENK'
   'MAPCEFGVLNSLANVLSQHLNQKDTLMQRLRNGLQNCATHTQPFWGSLTNRTRPPSVQVA'
   'KTTPFNTREPVMLACYVWGFYPAEVTITWRKNGKLVMPHSSAHKTAQPNGDWTYQTLSHL'
   'ALTPSYGDTYTCVVEHIGAPEPILRDWSYTPLPGSNYSEGWHIS'
);
INSERT INTO protein_sequence VALUES ( 'HLA-DMB', 263,
   'MITFLPLLLGLSLGCTGAGGFVAHVESTCLLDDAGTPKDFTYCISFNKDLLTCWDPEENK'
   'MAPCEFGVLNSLANVLSQHLNQKDTLMQRLRNGLQNCATHTQPFWGSLTNRTRPPSVQVA'
   'KTTPFNTREPVMLACYVWGFYPAEVTITWRKNGKLVMPHSSAHKTAQPNGDWTYQTLSHL'
   'ALTPSYGDTYTCVVEHIGAPEPILRDWTPGLSPMQTLKVSVSAVTLGLGLIIFSLGVISW'
   'RRAGHSSYTPLPGSNYSEGWHIS'
);
INSERT INTO protein_sequence VALUES ( 'H2-DMb1', 261,
   'MAALWLLLLVLSLHCMGAGGFVAHVESTCVLDDAGTPQDFTYCVSFNKDLLACWDPIVGK'
   'IVPCEFGVLYPLAENFSRILNKEESLLQRLQNGLPDCASHTQPFWNALTHRTRPPSVRVA'
   'QTTPFNTREPVMLACYVWGFYPADVTITWMKNGQLVPSHSNKEKTAQPNGDWTYQTVSYL'
   'ALTPSYGDVYTCVVQHSGTSEPIRGDWTPGLSPIQTVKVSVSAATLGLGFIIFCVGFFRW'
   'RKSHSSSYTPLSGSTYPEGRH'
);
INSERT INTO protein_sequence VALUES ( 'H2-DMb2', 261,
   'MAALWLLLLVLSLHCMGAGGFVAHVESTCVLNDAGTPQDFTYCVSFNKDLLACWDPDVGK'
   'IVPCEFGVLSRLAEIISNILNEQESLIHRLQNGLQDCATHTQPFWDVLTHRTRAPSVRVA'
   'QTTPFNTREPVMLACYVWGFYPADVTITWMKNGQLVPSHSNKEKTAQPNGDWTYQTVSYL'
   'ALTPSYGDVYTCVVQHSGTSEPIRGDWTPGLSPIQTVKVSVSAATLGLGFIIFCVGFFRW'
   'RKSHSSSYTPLPGSTYPEGRH'
);



CREATE TABLE mrna_sequence (
        mrna_id          varchar(32),
        length           int,
        seq              text
);

INSERT INTO mrna_sequence VALUES ( 'NM_002118.3', 1358,
   'cctgtttgggacactggactcccgtgagctggaaggaacagatttaatatctaggggctg'
   'ggtatccccacatcactcatttggggggtcaagggacccgggcaatatagtattctgctc'
   'agtgtctggagatcatctacccaggctggggcttctgggacaggcgaggacccacggacc'
   'ctggaagagctggtccaggggactgaactcccggcatctttacagagcagagcatgatca'
   'cattcctgccgctgctgctggggctcagcctgggctgcacaggagcaggtggcttcgtgg'
   'cccatgtggaaagcacctgtctgttggatgatgctgggactccaaaggatttcacatact'
   'gcatctccttcaacaaggatctgctgacctgctgggatccagaggagaataagatggccc'
   'cttgcgaatttggggtgctgaatagcttggcgaatgtcctctcacagcacctcaaccaaa'
   'aagacaccctgatgcagcgcttgcgcaatgggcttcagaattgtgccacacacacccagc'
   'ccttctggggatcactgaccaacaggacacggccaccatctgtgcaagtagccaaaacca'
   'ctccttttaacacgagggagcctgtgatgctggcctgctatgtgtggggcttctatccag'
   'cagaagtgactatcacgtggaggaagaacgggaagcttgtcatgcctcacagcagtgcgc'
   'acaagactgcccagcccaatggagactggacataccagaccctctcccatttagccttaa'
   'ccccctcttacggggacacttacacctgtgtggtagagcacattggggctcctgagccca'
   'tccttcgggactggacacctgggctgtcccccatgcagaccctgaaggtttctgtgtctg'
   'cagtgactctgggcctgggcctcatcatcttctctcttggtgtgatcagctggcggagag'
   'ctggccactctagttacactcctcttcctgggtccaattattcagaaggatggcacattt'
   'cctagaggcagaatcctacaacttccactccaagtgagaaggagattcaaactcaatgat'
   'gctaccatgcctctccaacatcttcaaccccctgacattatcttggatcctatggtttct'
   'ccatccaattctttgaatttcccagtctcccctatgtaaaacttagcaacttgggggacc'
   'tcattcctgggactatgctgtaaccaaattattgtccaaggctatatttctgggatgaat'
   'ataatctgaggaagggagttaaagaccctcctggggctctcagtgtgccatagaggacag'
   'caactggtgattgtttcagagaaataaactttggtgga'
);
 INSERT INTO mrna_sequence VALUES ( 'NM_010387.2', 1285,
   'ggagttactgggtacaagtttaggatctcaggaggggctgagtgacttggcgccacataa'
   'gcagcaaggagcaaggggcctgagcaagaggtaccatatttacctcagtgtgtgaagatc'
   'atttgtccaggctggggcaggagagaacctgaggcccctgcaggaggtgcccaggggcct'
   'ggccttcctgcaccttcagagagtgaaacatggctgcactctggctgctgctgctggtcc'
   'tcagtctggactgtatgggggcaggtggctttgtggctcatgtggaaagcacgtgcgtgc'
   'tggatgatgctgggaccccacaggacttcacatactgtgtttccttcaacaaagatctgc'
   'tggcctgctgggatccagatgtgggaaaaatagtcccctgtgaatttggggtgctgtatc'
   'catgggccgaaaatttttcaaggatcctcaacaaagaagagagccttctccagcgtttgc'
   'aaaacgggcttctggactgtgcctcccacacccagcccttctggaatgcgctgacccaca'
   'gaacgagagcgccatctgtccgagtagcccaaaccacaccttttaacacaagggagccgg'
   'tgatgctggcctgctacgtctggggcttctatccagcggatgtgaccatcacatggatga'
   'agaatgggcagcttgtcccttcccacagcaacaaggagaagacggctcagcccaatggag'
   'actggacataccagacagtctcctacctagccctaaccccttcctacggggacgtctaca'
   'cctgcgtggttcagcacagcgggacctctgagcccatccgaggggactggacacctgggc'
   'tgtcccccatccagacagtgaaggtctctgtgtctgcagccaccctgggcctgggcttca'
   'tcatcttctgtgttggcttcttcagatggcgcaagtctcattcctccagctacactcctc'
   'tctctggatccacctacccggaaggacagcattagagagcagaacccggaaccaaggaga'
   'ttcagactcctgaggattccttaatgccccaacatcttcaggacaccccactttcttgtg'
   'tcatactgcctctattcaggtccccttcctgaaataaatattagtagtttgggggggtat'
   'ttataatgaagtctgtcccaggtgggggagctgaggtgagctgaaatgaggtgggggttc'
   'aaggcctcctgagagcccctccttgtcacgagggcaccgtgtcttaggtgatcactaaga'
   'aataaactggtggacttttgatttc'
);
INSERT INTO mrna_sequence VALUES ( 'NM_010388.1', 786,
   'atggctgcactctggctgctgctgctggtcctcagtctgcactgtatgggggcaggtggc'
   'tttgtggctcatgtggaaagcacgtgcgtgctgaatgatgctgggaccccacaggacttc'
   'acatactgtgtttccttcaacaaagatctgctggcctgctgggatccagatgtgggaaaa'
   'atagtcccctgtgaatttggggtgctgtctagattggctgaaataatttcaaatatcctc'
   'aacgaacaggagagccttattcatcgcttgcaaaacgggcttcaggactgtgccacccac'
   'acccaacctttctgggatgtgctgacccacagaacgagagcgccatctgtccgagtagcc'
   'caaaccacaccttttaacacaagggagcccgtgatgctggcctgctacgtctggggcttc'
   'tatccagcggatgtgaccatcacatggatgaagaatgggcagcttgtcccttcccacagc'
   'aacaaggagaagacggctcagcccaatggagactggacataccagacagtctcctaccta'
   'gccctaaccccttcctacggggacgtctacacctgcgtggttcagcacagcgggacctct'
   'gagcccatccgcggggactggacacctgggctgtcccccatccagacagtgaaggtctct'
   'gtgtctgcagccaccctgggcctgggcttcatcatcttctgtgttggcttcttcagatgg'
   'cgcaagtctcattcctccagctacactcctctccccggatccacctacccagaaggacgg'
   'cactag'
);
INSERT INTO mrna_sequence VALUES ( 'ASAP_55845', 2104,
   'gggaaacacacaggggtgtttagagtttggcgaaaggcaggtgagctctgggcactgacc'
   'cgtcaccagctatttttcaaggagtctgagaggtgttaacctgcggtctaccccgtgaga'
   'ttgctcagagtgtaggaggatatggtttactagctccggaaagcagctattataactgag'
   'gaggaaatgaagcttgactggctagaacagaagcaacaatggaggcccatggagggattt'
   'tccaggcccctattcctgatctccatggtggcgctgcttcccttattctgcagtcttgct'
   'ttgagaccagacaattctgtactctgtctgtgccttcttccttctcagcagccctgcctc'
   'tgccacctgccccagaagggctctgggtcctctcatctcaggacagacaagggtttttgt'
   'aattatcttcttgggtaacctccctgtaaggaataggagaggttatctggtcctggtctt'
   'ttgggagagcattgagaagaaaaagttaaaccagtgggcagcccaggctgcatacatcct'
   'gggaatattgcgattattctctccagtaatctacggaaatctactggttgttctgcagaa'
   'aaagaattaagagagacaaggagacctgttgtctaagactaaggcaggatgacgtttacc'
   'tagtaactgatgatgctaggctgaggcactcagtgatttgtctctacatttgtccctgcc'
   'tacctagccaatctgtccctgtttgggacactggactcccgtgagctggaaggaacagat'
   'ttaatatctaggggctgggtatccccacatcactcatttggggggtcaagggacccgggc'
   'aatatagtattctgctcagtgtctggagatcatctacccaggctggggcttctgggacag'
   'gcgaggacccacggaccctggaagagctggtccaggggactgaactcccggcatctttac'
   'agagcagagcatgatcacattcctgccgctgctgctggggctcagcctgggctgcacagg'
   'agcaggtggcttcgtggcccatgtggaaagcacctgtctgttggatgatgctgggactcc'
   'aaaggatttcacatactgcatctccttcaacaaggatctgctgacctgctgggatccaga'
   'ggagaataagatggccccttgcgaatttggggtgctgaatagcttggcgaatgtcctctc'
   'acagcacctcaaccaaaaagacaccctgatgcagcgcttgcgcaatgggcttcagaattg'
   'tgccacacacacccagcccttctggggatcactgaccaacaggacacggccaccatctgt'
   'gcaagtagccaaaaccactccttttaacacgagggagcctgtgatgctggcctgctatgt'
   'gtggggcttctatccagcagaagtgactatcacgtggaggaagaacgggaagcttgtcat'
   'gcctcacagcagtgcgcacaagactgcccagcccaatggagactggacataccagaccct'
   'ctcccatttagccttaaccccctcttacggggacacttacacctgtgtggtagagcacat'
   'tggggctcctgagcccatccttcgggactggacacctgggctgtcccccatgcagaccct'
   'gaaggtttctgtgtctgcagtgactctgggcctgggcctcatcatcttctctcttggtgt'
   'gatcagctggcggagagctggccactctagttacactcctcttcctgggtccaattattc'
   'agaaggatggcacatttcctagaggcagaatcctacaacttccactccaagtgagaagga'
   'gattcaaactcaatgatgctaccatgcctctccaacatcttcaaccccctgacattatct'
   'tggatcctatggtttctccatccaattctttgaatttcccagtctcccctatgtaaaact'
   'tagcaacttgggggacctcattcctgggactatgctgtaaccaaattattgtccaaggct'
   'atatttctgggatgaatataatctgaggaagggagttaaagaccctcctggggctctcag'
   'tgtgccatagaggacagcaactggtgattgtttcagagaaataaactttggtggaaatat'
   'tgtt'
);
INSERT INTO mrna_sequence VALUES ( 'ASAP_55846', 1951,
   'gggaaacacacaggggtgtttagagtttggcgaaaggcaggtgagctctgggcactgacc'
   'cgtcaccagctatttttcaaggagtctgagaggtgttaacctgcggtctaccccgtgaga'
   'ttgctcagagtgtaggaggatatggtttactagctccggaaagcagctattataactgag'
   'gaggaaatgaagcttgactggctagaacagaagcaacaatggaggcccatggagggattt'
   'tccaggcccctattcctgatctccatggtggcgctgcttcccttattctgcagtcttgct'
   'ttgagaccagacaattctgtactctgtctgtgccttcttccttctcagcagccctgcctc'
   'tgccacctgccccagaagggctctgggtcctctcatctcaggacagacaagggtttttgt'
   'aattatcttcttgggtaacctccctgtaaggaataggagaggttatctggtcctggtctt'
   'ttgggagagcattgagaagaaaaagttaaaccagtgggcagcccaggctgcatacatcct'
   'gggaatattgcgattattctctccagtaatctacggaaatctactggttgttctgcagaa'
   'aaagaattaagagagacaaggagacctgttgtctaagactaaggcaggatgacgtttacc'
   'tagtaactgatgatgctaggctgaggcactcagtgatttgtctctacatttgtccctgcc'
   'tacctagccaatctgtccctgtttgggacactggactcccgtgagctggaaggaacagat'
   'ttaatatctaggggctgggtatccccacatcactcatttggggggtcaagggacccgggc'
   'aatatagtattctgctcagtgtctggagatcatctacccaggctggggcttctgggacag'
   'gcgaggacccacggaccctggaagagctggtccaggggactgaactcccggcatctttac'
   'agagcagagcatgatcacattcctgccgctgctgctggggctcagcctgggctgcacagg'
   'agcaggtggcttcgtggcccatgtggaaagcacctgtctgttggatgatgctgggactcc'
   'aaaggatttcacatactgcatctccttcaacaaggatctgctgacctgctgggatccaga'
   'ggagaataagatggccccttgcgaatttggggtgctgaatagcttggcgaatgtcctctc'
   'acagcacctcaaccaaaaagacaccctgatgcagcgcttgcgcaatgggcttcagaattg'
   'tgccacacacacccagcccttctggggatcactgaccaacaggacacggccaccatctgt'
   'gcaagtagccaaaaccactccttttaacacgagggagcctgtgatgctggcctgctatgt'
   'gtggggcttctatccagcagaagtgactatcacgtggaggaagaacgggaagcttgtcat'
   'gcctcacagcagtgcgcacaagactgcccagcccaatggagactggacataccagaccct'
   'ctcccatttagccttaaccccctcttacggggacacttacacctgtgtggtagagcacat'
   'tggggctcctgagcccatccttcgggactggagatggcacatttcctagaggcagaatcc'
   'tacaacttccactccaagtgagaaggagattcaaactcaatgatgctaccatgcctctcc'
   'aacatcttcaaccccctgacattatcttggatcctatggtttctccatccaattctttga'
   'atttcccagtctcccctatgtaaaacttagcaacttgggggacctcattcctgggactat'
   'gctgtaaccaaattattgtccaaggctatatttctgggatgaatataatctgaggaaggg'
   'agttaaagaccctcctggggctctcagtgtgccatagaggacagcaactggtgattgttt'
   'cagagaaataaactttggtggaaatattgtt'
);
INSERT INTO mrna_sequence VALUES ( 'ASAP_55847', 2068,
   'gggaaacacacaggggtgtttagagtttggcgaaaggcaggtgagctctgggcactgacc'
   'cgtcaccagctatttttcaaggagtctgagaggtgttaacctgcggtctaccccgtgaga'
   'ttgctcagagtgtaggaggatatggtttactagctccggaaagcagctattataactgag'
   'gaggaaatgaagcttgactggctagaacagaagcaacaatggaggcccatggagggattt'
   'tccaggcccctattcctgatctccatggtggcgctgcttcccttattctgcagtcttgct'
   'ttgagaccagacaattctgtactctgtctgtgccttcttccttctcagcagccctgcctc'
   'tgccacctgccccagaagggctctgggtcctctcatctcaggacagacaagggtttttgt'
   'aattatcttcttgggtaacctccctgtaaggaataggagaggttatctggtcctggtctt'
   'ttgggagagcattgagaagaaaaagttaaaccagtgggcagcccaggctgcatacatcct'
   'gggaatattgcgattattctctccagtaatctacggaaatctactggttgttctgcagaa'
   'aaagaattaagagagacaaggagacctgttgtctaagactaaggcaggatgacgtttacc'
   'tagtaactgatgatgctaggctgaggcactcagtgatttgtctctacatttgtccctgcc'
   'tacctagccaatctgtccctgtttgggacactggactcccgtgagctggaaggaacagat'
   'ttaatatctaggggctgggtatccccacatcactcatttggggggtcaagggacccgggc'
   'aatatagtattctgctcagtgtctggagatcatctacccaggctggggcttctgggacag'
   'gcgaggacccacggaccctggaagagctggtccaggggactgaactcccggcatctttac'
   'agagcagagcatgatcacattcctgccgctgctgctggggctcagcctgggctgcacagg'
   'agcaggtggcttcgtggcccatgtggaaagcacctgtctgttggatgatgctgggactcc'
   'aaaggatttcacatactgcatctccttcaacaaggatctgctgacctgctgggatccaga'
   'ggagaataagatggccccttgcgaatttggggtgctgaatagcttggcgaatgtcctctc'
   'acagcacctcaaccaaaaagacaccctgatgcagcgcttgcgcaatgggcttcagaattg'
   'tgccacacacacccagcccttctggggatcactgaccaacaggacacggccaccatctgt'
   'gcaagtagccaaaaccactccttttaacacgagggagcctgtgatgctggcctgctatgt'
   'gtggggcttctatccagcagaagtgactatcacgtggaggaagaacgggaagcttgtcat'
   'gcctcacagcagtgcgcacaagactgcccagcccaatggagactggacataccagaccct'
   'ctcccatttagccttaaccccctcttacggggacacttacacctgtgtggtagagcacat'
   'tggggctcctgagcccatccttcgggactggacacctgggctgtcccccatgcagaccct'
   'gaaggtttctgtgtctgcagtgactctgggcctgggcctcatcatcttctctcttggtgt'
   'gatcagctggcggagagctggccactctagatggcacatttcctagaggcagaatcctac'
   'aacttccactccaagtgagaaggagattcaaactcaatgatgctaccatgcctctccaac'
   'atcttcaaccccctgacattatcttggatcctatggtttctccatccaattctttgaatt'
   'tcccagtctcccctatgtaaaacttagcaacttgggggacctcattcctgggactatgct'
   'gtaaccaaattattgtccaaggctatatttctgggatgaatataatctgaggaagggagt'
   'taaagaccctcctggggctctcagtgtgccatagaggacagcaactggtgattgtttcag'
   'agaaataaactttggtggaaatattgtt'
);
INSERT INTO mrna_sequence VALUES ( 'ASAP_55848', 1987,
   'gggaaacacacaggggtgtttagagtttggcgaaaggcaggtgagctctgggcactgacc'
   'cgtcaccagctatttttcaaggagtctgagaggtgttaacctgcggtctaccccgtgaga'
   'ttgctcagagtgtaggaggatatggtttactagctccggaaagcagctattataactgag'
   'gaggaaatgaagcttgactggctagaacagaagcaacaatggaggcccatggagggattt'
   'tccaggcccctattcctgatctccatggtggcgctgcttcccttattctgcagtcttgct'
   'ttgagaccagacaattctgtactctgtctgtgccttcttccttctcagcagccctgcctc'
   'tgccacctgccccagaagggctctgggtcctctcatctcaggacagacaagggtttttgt'
   'aattatcttcttgggtaacctccctgtaaggaataggagaggttatctggtcctggtctt'
   'ttgggagagcattgagaagaaaaagttaaaccagtgggcagcccaggctgcatacatcct'
   'gggaatattgcgattattctctccagtaatctacggaaatctactggttgttctgcagaa'
   'aaagaattaagagagacaaggagacctgttgtctaagactaaggcaggatgacgtttacc'
   'tagtaactgatgatgctaggctgaggcactcagtgatttgtctctacatttgtccctgcc'
   'tacctagccaatctgtccctgtttgggacactggactcccgtgagctggaaggaacagat'
   'ttaatatctaggggctgggtatccccacatcactcatttggggggtcaagggacccgggc'
   'aatatagtattctgctcagtgtctggagatcatctacccaggctggggcttctgggacag'
   'gcgaggacccacggaccctggaagagctggtccaggggactgaactcccggcatctttac'
   'agagcagagcatgatcacattcctgccgctgctgctggggctcagcctgggctgcacagg'
   'agcaggtggcttcgtggcccatgtggaaagcacctgtctgttggatgatgctgggactcc'
   'aaaggatttcacatactgcatctccttcaacaaggatctgctgacctgctgggatccaga'
   'ggagaataagatggccccttgcgaatttggggtgctgaatagcttggcgaatgtcctctc'
   'acagcacctcaaccaaaaagacaccctgatgcagcgcttgcgcaatgggcttcagaattg'
   'tgccacacacacccagcccttctggggatcactgaccaacaggacacggccaccatctgt'
   'gcaagtagccaaaaccactccttttaacacgagggagcctgtgatgctggcctgctatgt'
   'gtggggcttctatccagcagaagtgactatcacgtggaggaagaacgggaagcttgtcat'
   'gcctcacagcagtgcgcacaagactgcccagcccaatggagactggacataccagaccct'
   'ctcccatttagccttaaccccctcttacggggacacttacacctgtgtggtagagcacat'
   'tggggctcctgagcccatccttcgggactggagttacactcctcttcctgggtccaatta'
   'ttcagaaggatggcacatttcctagaggcagaatcctacaacttccactccaagtgagaa'
   'ggagattcaaactcaatgatgctaccatgcctctccaacatcttcaaccccctgacatta'
   'tcttggatcctatggtttctccatccaattctttgaatttcccagtctcccctatgtaaa'
   'acttagcaacttgggggacctcattcctgggactatgctgtaaccaaattattgtccaag'
   'gctatatttctgggatgaatataatctgaggaagggagttaaagaccctcctggggctct'
   'cagtgtgccatagaggacagcaactggtgattgtttcagagaaataaactttggtggaaa'
   'tattgtt'
);
INSERT INTO mrna_sequence VALUES ( 'BC052864.1', 1544,
   'aagaggtaatcccaaggagcaaggggcctgagcaagaggtaccatatttacctcagtgtg'
   'tgaagatcatttgcccaggctggggcaggagagaacctgaggcccttgcaggaggtgccc'
   'aggggcctggccttcctgcaccttcagagagtggaacatggctgcactctggctgctgct'
   'gctggtcctcagtctgcactgtatgggggcagccacatctctaacaccatgaggaatatt'
   'ttaaaggacaaagggttcataggaagacagccaggcagagctcaggtgcagtagcttctg'
   'cccccaaaaggtggctttgtggctcatgtggaaagcacgtgcgtgctgaatgatgctggg'
   'accccacaggacttcacatactgtgtttccttcaacaaagatctgctggcctgctgggat'
   'ccagatgtgggaaaaatagtcccctgtgaatttggggtgctgtctagattggctgaaata'
   'atttcaaatatcctcaacgaacaggagagccttattcatcgcttgcaaaacgggcttcag'
   'gactgtgccacccacacccaacctttctgggatgtgctgacccacagaacgagagcgcca'
   'tctgtccgagtagcccaaaccacaccttttaacacaagggagcccgtgatgctggcctgc'
   'tacgtctggggcttctatccagcggatgtgaccatcacatggatgaagaatgggcagctt'
   'gtcccttcccacagcaacaaggagaagacggctcagcccaatggagactggacataccag'
   'acagtctcctacctagccctaaccccttcctacggggacgtctacacctgcgtggttcag'
   'cacagcgggacctctgagcccatccgcggggactggacacctgggctgtcccccatccag'
   'acagtgaaggtctctgtgtctgcagccaccctgggcctgggcttcatcatcttctgtgtt'
   'ggcttcttcagatggcgcaagtctcattcctccagctacactcctctccccggatccacc'
   'tacccagaaggacggcactagaaagcagaacccagaaccaaggagattcagactcctgag'
   'gattccttcatgcccccaatatcttcaggacaccccattttcttgtgtcatactgcctct'
   'attcagtttcccttcccaatgtaatttttttttttgttttttgtttttttgagacagggt'
   'ttctctgtatagccctggctgtcctggaactcactttgtagaccaggctggcctcaaact'
   'cagaaatccacctgcctctgcctccagagtgctgggattaaaggcgtacgccaccatgcc'
   'cggcttccgatgtgtaacagcttgggaggtattcataatgaagtctgtctcaggtgtttt'
   'ctgaagtgagctgatctaaggagggggttcaaggtcttctgagagcccctccttgtcaca'
   'agggcaccgtgtcataggtggtcactaagaaataaactggtggaattcctggcttcaaaa'
   'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaag'
);



CREATE TABLE genomic_sequence (
        gene      varchar(32),
        location  loc,
        length    int,
        seq       text
);

INSERT INTO genomic_sequence VALUES ( 'HLA-DMB', 'NT_007592.7[7813399..7823803]~', 10405,
   'tgtaatcctagcactttaggaggctgaggtgggtggatcacttgaggtcaggagttcaag'
   'aacagcctggccaacatgatgaaaccctgtctctaccaaaaaaaaaaaaaagacaaaaac'
   'taaccaggagtggtggcacatgactgtaaccccagctactcaagtggctgaggcatgaga'
   'gtcatttgaacccaggaggcgaagattgcagtgagccgagattatcccactgtactccag'
   'cctaggcgacagagtgagactttcaaaaaaaaaacctgtgaaaaaaataaatacgcaaat'
   'acataaaatctgccttttcaagacacacacgtgaccaagaagcatatgaaacaatgttca'
   'acattactaatgattagaaaaatgcaaatcaaaatcataatgagataccgtctcacacca'
   'gtcagaatggctattattaaaaagtcaaaaaataacaaatgttggagaggttgcagagaa'
   'aacggaaggcttatacactgctggtgggaacataaattagttcagccattgaggaaagca'
   'gtttggcaatttctcaagaaccttaaaacagagctaccattcgtcccaggaatcccatta'
   'ttaggcatatacccaaaggagtatacattgttctaccataaggacatatgcacatgaatg'
   'ctcactgcagcagtattcataatagcaaagacatggaatcagcctaaatgcccaccaaca'
   'gtagactgtataaagaaaatgtggtacatatacaccatggaatactccacagctagaaag'
   'gtcgtgctcacgtcttttgcagcatcatggagctgggggctgttatcctaggcaaaccta'
   'cacaggagcaggaaatgaatactgcatgtctcactttatagtggagctaacatgagacac'
   'atggacacaaaaaggaataatagacactgggccctacttgagggtggaggatgggaggag'
   'aagaggatcaaaacactacctatcagatactatacttattacctgggtgatgaaataaat'
   'ttttacgccaaatcccgatgacacacaatttacctatataacaaacctgcatgtgtaccc'
   'ttgaacctaaaacaaaggttaaaataatttaaaataaataaaaaataaaatcttacttgg'
   'tattctcaaaaaataaaaaacaaaatctgtcttttcaggggaagaaaagtaggaaagctt'
   'tatctcattttcctagtggcttcataatgcagggacctgcccccagggaacagggtatag'
   'taggggaaacacacaggggtgtttagagtttggcgaaaggcaggtgagctctgggcactg'
   'acccgtcaccagctatttttcaaggagtctgagaggtgttaacctgcggtctaccccgtg'
   'agattgctcagagtgtaggaggatatggtttactagctccggaaagcagctattataact'
   'gaggaggaaatgaagcttgactggctagaacagaagcaacaatggaggcccatggaggga'
   'ttttccaggcccctattcctgatctccatggtggcgctgcttcccttattctgcagtctt'
   'gctttgagaccagacaattctgtactctgtctgtgccttcttccttctcagcagccctgc'
   'ctctgccacctgccccagaagggctctgggtcctctcatctcaggacagacaagggtttt'
   'tgtaattatcttcttgggtaacctccctgtaaggaataggagaggttatctggtcctggt'
   'cttttgggagagcattgagaagaaaaagttaaaccagtgggcagcccaggctgcatacat'
   'cctgggaatattgcgattattctctccagtaatctacggaaatctactggttgttctgca'
   'gaaaaagaattaagagagacaaggagacctgttgtctaagactaaggcaggatgacgttt'
   'acctagtaactgatgatgctaggctgaggcactcagtgatttgtctctacatttgtccct'
   'gcctacctagccaatctgtccctgtttgggacactggactcccgtgagctggaaggaaca'
   'gatttaatatctaggggctgggtatccccacatcactcatttggggggtcaagggacccg'
   'ggcaatatagtattctgctcagtgtctggagatcatctacccaggctggggcttctggga'
   'caggcgaggacccacggaccctggaagagctggtccaggggactgaactcccggcatctt'
   'tacagagcagagcatgatcacattcctgccgctgctgctggggctcagcctgggctgcac'
   'aggagcaggtaaggacacttcttctggggactctcccttcccctgctcctgtttcagggt'
   'aagggtgttccgttttgtaattgcatttgacaccccagatagtttgtctccctggtatac'
   'attcctatagcactttgtactttgtagcaattttaatgtaattaatctgtataattatct'
   'gtgcagtgtatattccctgctggaatataggcaaggacaatgttcatcttatttattgct'
   'gcctcctcagctcctagcacagtgccttgcatgcagcaagtgcttcataaatatgtgcga'
   'agtgaatatttaatatttccagcacaatacaaggctgactctttctcttgaccctttttc'
   'tctctcaataatttgccttactgaaggtctgtgttctgggcaaattgtcatgtttaaaca'
   'tgcaaataatctcggggggctactcctatccctgtgcttagtcttgcataaagaggagac'
   'tggatctaaaaacttatctactacttctactgactccctcaaatcagactttcagaaact'
   'tcagtgtatgagcttggtcagtagatgttccctgagcaggaaatctgtgccagactagct'
   'ggatgtcaccaaggcttaggttctgagctgaatataggaaaaatcaactttttttcttct'
   'atatgctcacactcaacacttctttgaccaactgtgtgaggttttttttttttttttact'
   'cataccaaccaattctcctatattagctggatatcctataattcaattccattgtgacat'
   'taactagagttaacatagacaccaaaggttaaagactcagtcccataagactgcctccat'
   'ttcagacaccaatcacaagtagtaggttcccaaattacccacatcttctgtccaacttgc'
   'ctacaaatcagaggttcccatgaccccctccttggggttggtaatttgctaaagtggctt'
   'atggaactcaggaaaagtttacttattattgtagattttttacaaaggatattttaattg'
   'ataataataattataaatattcatggggtggataatgatgttttagtacatgtaatgtac'
   'agtgatcagatcagatcatcatctcatttatcatttctttgtgttggaaacattccatat'
   'ccttcttctagcgatttgaaatgatataaagtattattgttaatgacagtcatcccacag'
   'tggtatagaacactagatcataattttgcatcctttaacaaaggatattttaaagcatac'
   'aaaggaacatccagatgaagagataccagatctggaagggtcccaatcacaggagctctg'
   'tccccacagaattggggtacttcacctcctggcatgtggatgtgtttaccaactgagaag'
   'ttctctgaactccatagttccgggatttttatggaggcttcatcatgtaggcatgactga'
   'ttattaactcaatctccagccccttccccttcagggagtatgggggatgggactaaaagt'
   'tccagacttctaatcatgacttggtctttctggtgaccagcccctcctgcaggagcccac'
   'caagagtacctcattagaacaaaagacactcctgttatctaggaaattctaagcgattag'
   'gcactctatgtcaggaaccagggtcaaagacaaagctctgtgcagagctcctaaatatac'
   'gtctgtatgttttatatatttattatttgtgtatatttattatttatatatttatttatt'
   'tattgccaggccagtagaagacattgacctgttctcccttccctggctcctctaggtggc'
   'ttcgtggcccatgtggaaagcacctgtctgttggatgatgctgggactccaaaggatttc'
   'acatactgcatctccttcaacaaggatctgctgacctgctgggatccagaggagaataag'
   'atggccccttgcgaatttggggtgctgaatagcttggcgaatgtcctctcacagcacctc'
   'aaccaaaaagacaccctgatgcagcgcttgcgcaatgggcttcagaattgtgccacacac'
   'acccagcccttctggggatcactgaccaacaggacacgtgaggagagaggggtgcagagg'
   'ggctaccaggaagtgcagttaggagggcaggccagggaggatcccacagtggcccagggg'
   'tttgagatttgagcagcaaataagagaaaatgtgtggatctgaaatgtagaaagacggag'
   'gattgaacctcaaggggaacaaggtggctgacgtgagtggaacaggagtaaagaagggga'
   'ggtgaggcttgaaccgcgaggtgccatgtggggagcttatgcagaggctggggcatctca'
   'ggatgcatacccaagatgttcttgccttgttatcccagattttgatgttccagatctgat'
   'gtgggcccaggcatgggaatatttggaatcccaggggattctgacacatgctttttctca'
   'cccttaaactcttgcattgacaatggcttgaagtttgtgaaagtaaacttgaagatctcc'
   'acagtacagaacagtgtgtctcaagggtggtttctgaaccacctttctcagaattgcctg'
   'gaggaggtgcttgttaaagatgcaagccccttagtaccactccagatctgttgaaagaaa'
   'gtatctggggatacagcctaggaaatctgcattttaacataattccttggatttttattt'
   'aagattgtgtttgaaaaatgtcaagatagaggcaagcaagaggatcacctaggagagtaa'
   'attagtaaaagatggcagtattagcaatctctttagtttgactacattcattccaaattt'
   'aagagtgagtcctaagttaggcttgtttccttgaactatgtgaggagaaaaagctttaac'
   'tagcaaaagaacgtattaaacaagatttggagaaaaattccttttccaccttaaaaaaac'
   'ccaatgtacaactctggattactcttagcttccttatttcaaatactttccagtttatgt'
   'acttgaaataaatacaacaacttctagaacagcttgcagttcagatctggcttttactaa'
   'ttgtaatcaaacataattctggaggaggaaagaaagaaaggggcaatgaaggaatgggag'
   'agaagaaagagtaatgcaggaatacattctaacggttccccttcaaggggcagcatggca'
   'gagggggctggggtggaaagtgggttgcaaaatctacgaagagttgcgatagggaagaaa'
   'ccaggttgaggaagcagccagaatgtcaccctccttcctaaacatgtttttttctcctat'
   'gcagggccaccatctgtgcaagtagccaaaaccactccttttaacacgagggagcctgtg'
   'atgctggcctgctatgtgtggggcttctatccagcagaagtgactatcacgtggaggaag'
   'aacgggaagcttgtcatgcctcacagcagtgcgcacaagactgcccagcccaatggagac'
   'tggacataccagaccctctcccatttagccttaaccccctcttacggggacacttacacc'
   'tgtgtggtagagcacattggggctcctgagcccatccttcgggactggagtaagtgtatg'
   'gcagatggatggaattagggtcaaagcagagaaaatgagatgtggatcgatacatggtac'
   'atggtagacagcgaagtgctgaaaatggggactgagtctggaggaacttacggggggctt'
   'aggaccagaatggggaaatgggataaagaaatggaaatatttaggttggtgcaaaagtaa'
   'ttgcagtttttgccattactttcagtggcaaaaaccgcaattacttttgcaccagtttaa'
   'tatttagtctgtgctattgctgctctggtggtgtggttgatgttgctgcgtctatgtttg'
   'agggtgagaggggagcgtgcttgctttgaaatgaggatgtaaatttggcaatcatatttt'
   'cagaaccccaaattgtaatacactattctagcctccttagatttcaactattctggtgcc'
   'agaagcagatgggagctgaaggaatgatgaaggttgaagaaggggggcttttcttggtgt'
   'ggggcagtactgcatttggcctgctctaccaagcatacgggagtagtaaagccacggctg'
   'gcagaccatttggcatgcatgctcaggggccagtggataaagaattacttacagttcaaa'
   'cactgtttgaactcagtgtcgggagtagttaaaggtatcgtgagaagttgcacacagctt'
   'tggggactcttggaaaagaaagaggaagaaatgaggaagaggaagggtgtctacaaaggg'
   'ccagagaacaggatctcagatcagctgctgtaaccaggtttccccttgtgggaagtgttg'
   'tttcttgctgggcagttgggaagggaatggagaacagagaagagagtggaaatcacatgc'
   'tcacttgaactttcctggggaacgtctcctcacagcgtgcacaagagcctccctttagaa'
   'atggagtgttcattttatcatgggaaaagaatctgagtgggacatgattcagaacaggac'
   'cggcccaaggaagtgcaggggctgtggagtgggatggagacaagctctgaaaggacacat'
   'gggagatctagatgtagaaggtacacaagtagtaggataactcacaggatggatccactg'
   'gaggttaagacatgtggtaagacagtgtaataggaagctgctcagttggagaaagtaagg'
   'aagcaaacattgttaccgtgggggcaatggagaggacagtgaggagccctttatcctgat'
   'aagggtggctttgaggtaaaggaaggaaagaggatgccttgagaggccccactgtattag'
   'agaggacctggaagccaggatgctaattctggggagatggattccccaggcttactctag'
   'gagtagaggtccatgggacgagggtttgatttgagaaagatcattttcttgggagtgggt'
   'ggtgtgagctagacccttggagctgggataaaggaccttttaacccactgagaggtggct'
   'gcaataaatggaattgccctgggggtgagcaacagaaactgggtcaagtaagtttctatt'
   'ttttgcagcacctgggctgtcccccatgcagaccctgaaggtttctgtgtctgcagtgac'
   'tctgggcctgggcctcatcatcttctctcttggtgtgatcagctggcggagagctggcca'
   'ctctagtgagtgactcgctgaactcccatccccactcttggtcccactctctgcttactt'
   'tctgtttgtgattaactctctccttcctactgcatttgctatgaatactgctagatattt'
   'tcatccacaaagactggtataatcaagtatcttcctctcttaggttacactcctcttcct'
   'gggtccaattattcagaaggtaacatctctgttggtctgtttccctacttgccctttggt'
   'aggggtgcgggttagaggggtcagtgttgggttcaactaatcttgattattatatgggtg'
   'agcttccatgaggatctaggcaagggcatgatttaagctgccattgctaggattaagagc'
   'aggaaggagcatcctcctcttctaccaagtgggatgtctgtggagaggaggctgaaggtg'
   'cttcctttgtattagttgttggtgccctggagttttcagtatcactgtattaaggcatgg'
   'gatggttacagtgacaaacgatgggggcaagttgggttgaagcctcattatctccctttt'
   'atttattctgtaggatggcacatttcctagaggcagaatcctacaacttccactccaagt'
   'gagaaggagattcaaactcaatgatgctaccatgcctctccaacatcttcaaccccctga'
   'cattatcttggatcctatggtttctccatccaattctttgaatttcccagtctcccctat'
   'gtaaaacttagcaacttgggggacctcattcctgggactatgctgtaaccaaattattgt'
   'ccaaggctatatttctgggatgaatataatctgaggaagggagttaaagaccctcctggg'
   'gctctcagtgtgccatagaggacagcaactggtgattgtttcagagaaataaactttggt'
   'ggaaatattgtttttccatgtcttcttcctggggccctggggaaggaatatgggcaaagc'
   'agggactgaggttaattctcttctgcttgagtaggggagaaatcaatgccttcttccatt'
   'ttcccacttagacatgacagaatttggggccgttttctgatttataattcataaggagaa'
   'attcaactgtggtgggttggagtcacagagtatgggcaaggaagggaattaacagcttac'
   'tcacctcatacaggatcttatgaggattaaatgagttcatacttgtaaatggctaagaac'
   'accgccaggcacatagccagcctgcaatagtgacgttagctatattcgattattcaactt'
   'tctggccaggcattgtaccaggtgctttgatcctcatcacaaccgtaaggcagacccctc'
   'atacccctcaggattcaggggacagagcttaactccagattgagttctagacagttattt'
   'cttccataccctgaatgcagaagggaacatagcttgagtgattattatgtcttaggcact'
   'ggtctcagacctttatatttgtagctcattctcttctcacaataaccacacaagggacag'
   'attgtttccctctatgttacagacaaaagatgtgaggctcagagacatttaagtgacttg'
   'tccaaggtcaaagaacagatttctgtaggatgtttgtctacctgagctggaagtagcaga'
   'ttactttattctgaagaccctcatgctggtgagcacacatctcttcagagccaccgttcc'
   'attcccttctaccccaagaccaaggagagccctttgggggaatggactccaccctaagga'
   'agagaggatgctggctggtggtttgttgtcccacgaagggcgacacctgctggacacaga'
   'aacctagggtgtggaattgtttttggaattagagctagatactagaatatgggtaagaaa'
   'aagaaaccaagaaatgagttgatttggaacacctccataatttcttcagaagcatccttg'
   'gaattagagcatctcttctggaaggggttaacagaagaagtcagtggaaggaacttaatc'
   'tctacattttaccatttttatgtttcattttcattttttctattcactgtttttgttttt'
   'atttttgtttgtttgacaaagcaaattccttttgaaattctagtttagtctaggaatggg'
   'gggctttgggccttgtctatatctgggcagttttatttattatttttattttatttattt'
   'attttttttcgagacagagttttgctcttgttgcccaggctggagtgcaatggcgtgatc'
   'tcggcttattgcaacttctgcctcccatgttcaagcgattctcctgcctcagcctcccaa'
   'gtagctgagattacaggcgtgcaccaccatgcctggctaattttgtattttcttagtagg'
   'gatggggtttcaccatgttggtcaggctggtctcgatctcctgacctcaagtgatccacc'
   'tgcctcagcctcccaaagtgctgggattacaggcgtgagccaccgcactaggcctatctg'
   'gacagttttaaaggagaagctgcagatctgaagggtctagttctagtcacagcagtggga'
   'atcaaagtggcaggatcccagagaaaggaagtagagagttagctaatgggacggcttcca'
   'gttccttttctagagatttccagtgcaggcttttctctgccctaactttgtaggtttttt'
   'gttttataggaaaggctgtccccttccaggtaaggaatagggaaaagtatatgtaggtct'
   'gctaggatccagaaagtcagaatactataggtagaaaggggagttcttacacaggggaat'
   'gagtggtacttgaaaggaaggtggaagaagggtgatggtgcaccaattgtaggaggatga'
   'ggagaagagaatggatgctgcatgaggagaatggaatgtaaacataatggattgccaaaa'
   'aaggagtgcgtgtgtgtgtgtgtgt'
);
INSERT INTO genomic_sequence VALUES ( 'H2-DMb1', 'NT_039662.1[402109..409147]', 7039,
   'gagttactgggtacaagtttaggatctcaggaggggctgagtgacttggcgccacataag'
   'cagcaaggagcaaggggcctgagcaagaggtaccatatttacctcagtgtgtgaagatca'
   'tttgtccaggctggggcaggagagaacctgaggcccctgcaggaggtgcccaggggcctg'
   'gccttcctgcaccttcagagagtgaaacatggctgcactctggctgctgctgctggtcct'
   'cagtctggactgtatgggggcaggtaaggtaacctcctgaaccttctctgtcctgctcct'
   'gtttgggtaaaacatgttcatttttgctagctagcaggtctgagtgccccagagtagcca'
   'gtctccagactatggcattcctccgcattcctccagccctgtgcactgtattttacagca'
   'attttaataatgagccattctcatagactgtgtgaaggatgtccctgtggggacgtagga'
   'taggactgggtactgctgggtcctggttcctaacatgatgcctggcatgtcataagtgtt'
   'ctgtggcatcgaagtcaaggatatttccagcacagagcaagactgactacttcttgactc'
   'tgtttctttctctcctgtcccttctcttccccttcccttttgtctgtctgtctgtttgcc'
   'tgcctgtctgtctgtctgtttctaattcgagacagtcctgctctatatccagaaaagcct'
   'taaactcatggcaatcctcctgcctcagtgctgggatcacaagtgtgccaactgcattac'
   'ccttatgtcattgttaataaccggatgctcgccaggtctgttttggggtagacaaccatg'
   'catgcctcatgggaattttgggctgttcctcccttgtcatccagtctcacatacaaaagg'
   'aacagtgctaattgttttcaaccttgtgcacatgagcctcaagctcatcccaaacctatg'
   'ccctgccagatgtggaagtcaatcacgtcggatgatattggtagaagagtgggattaact'
   'ttaaaatgccttttctgtgttttgtttggttggctgttgttgtgttaggaaagcctgaaa'
   'aactgagttatttaaatttgttatcttaaaaccttagaccactgcaagtggaaagcaaca'
   'gcctgatttagtgtcagagccttggggaggtggctcagcaatgaagagaactgggtgatt'
   'ctgaagaggacccaggttcaattcccagcacccacatcaaggacaagtgggaagtcccag'
   'gattaccatgacttctgcccagcttggctgagttagagccccttggcttggaaaatggag'
   'agggcacagcgtctgtgcaaatagaccattattgttcatttactgcaagagtttaaaaac'
   'atttctctctcctgcttctctgtttctgtttgtctgtatgtctctctctttctctttctt'
   'tctgtctctctcactctctttctctgtttctctctgtctctctctctctctgtatgtgtg'
   'tgtgtgtgcatgagcgtgtgtgcactctcatccgtgcttgtctgaatgtgcaccacatct'
   'atgtagtgtctgatgaggccagaagtgactcagactctctggaactggggttatggggag'
   'ccattgggaataggtgctctagttggaaccctggtcttctgcaagagcaacataatttta'
   'aacatccagccacatctctaacaccatgaggaatattttaaagaacaaagggttcatagg'
   'aagaaagccaggcagagttcaggtgcagtagcttctgctccccaggaggtgtgtgtgccg'
   'atccccaccatatgaatgtgttcaccgactgggatggtctctgggccccataacctgaga'
   'tttttaggcttcatcaaatagacaggatttatttttaatccagactccagtcccttccct'
   'gctgctccagatttgagatttaaactcaggctcctaaagatggttccatctttcctctga'
   'cagggttctgccaaaactgaccttattagaacaagggactccatggtcactcagttacaa'
   'gggtttcagagctctgggtgaggaaccaagttaaagactagatattagggcagaaaatgc'
   'atctactcccctccccccaccataagtagtcataagggttttaggaactttgtgttagga'
   'tctatgaatgggcagaggccatctttgcaatcctgccatgcagactctgacctgccttcc'
   'cttctctggccccttcccccaggtggctttgtggctcatgtggaaagcacgtgcgtgctg'
   'gatgatgctgggaccccacaggacttcacatactgtgtttccttcaacaaagatctgctg'
   'gcctgctgggatccagatgtgggaaaaatagtcccctgtgaatttggggtgctgtatcca'
   'tgggccgaaaatttttcaaggatcctcaacaaagaagagagccttctccagcgtttgcaa'
   'aacgggcttctggactgtgcctcccacacccagcccttctggaatgcgctgacccacaga'
   'acgagtgagcagaggggcagtctgggagcacagccaggagggcagtggacaaggagatgc'
   'ttgagcaacaaaggggttaatacctgggcaggaagagacagtgtggacttgcaagaggca'
   'gcaggacatggagggagcagtgtggtaatggggacagactggaggaagaggatgtagtga'
   'gaaggaattgactaggaccagaagcagaagccaagcatgtcagggtagagatcctagcca'
   'gaagtccaccaatgactttccccattcctggctgttctttttatttattttaattagata'
   'tttcttcccattactggggactgaacccaggaccctgcacatgcctggcaagcactttac'
   'cagtgtgtatgtcctaggtccatttctactatgtgttctgaggcaggatttcccaaagtt'
   'gccaaagctggccttgaacttgtaactcttgtttcagtgttgcagccagctggaattgca'
   'ggcttgggtctccaagcctgttgctgttttattagctcagattttgttgttccatattta'
   'gaagggatgcagggtgtggggagatctgcagtgctccagggactccagtaaagtttctct'
   'tcctctggacacctttgcatagagaatcgctcatggaactgcttaaagctggtaacgttg'
   'tataaactttgaagatctccataggtcagagtgtcaggtgtgtcataagatacagtttct'
   'cagccacctttcagcatcacctgctcaaggtgcttactgaagatgcaagttcctgggtac'
   'cactctagacagggagaaaatacctttagtgaagcctagagagactgtatttttttttaa'
   'aaaagatttatttatttacatatgtaatgcatatgagtacactgccactttctccagata'
   'cagcagaagagggcatcagatcccgttatagatggttatgagccactatgtggtcgctgg'
   'gaattgaactcaggacctctggaagagcagtcggtgctcttaaccactgagccatctctc'
   'cagcccaagagtctgtattttaacataatttcttgcattttctcttaaaatcttacactg'
   'atagaggagagcaggaggatctcttgcgggggtgggggcggggcggggcgggataagcta'
   'gcagaaaatggagtcttagtaatctcatcttcaggcatggtggtacagacctgtaatgcc'
   'agcacttgggaagaggtaggagactaggagttaggaccatcaccagcctcagaggagtgt'
   'gggctatatgagagcacatcttagaaaacacacaagcatggggccatgcaggataagcac'
   'agatactatgcagacagttcaaggctcagatggggcatttcccaattgtgataaaaaatg'
   'actttggagaagaaaagaaagaggttatgagatattaagaggaagcctgagaggcaggag'
   'tgagttctgtttcccttttcaatgtgtggctgcagacagttttgaaaggatgaaatgaga'
   'cttccttaccaaccataactgcttctcccatgcaggagcgccatctgtccgagtagccca'
   'aaccacaccttttaacacaagggagccggtgatgctggcctgctacgtctggggcttcta'
   'tccagcggatgtgaccatcacatggatgaagaatgggcagcttgtcccttcccacagcaa'
   'caaggagaagacggctcagcccaatggagactggacataccagacagtctcctacctagc'
   'cctaaccccttcctacggggacgtctacacctgcgtggttcagcacagcgggacctctga'
   'gcccatccgaggggactggagtaagtgtgtgggaactcggactttggtggttgggaaggg'
   'acatggatattttggctgaggtagtgagacgtgcaccggtgcgtggtccatgtaagagaa'
   'ggggatgctgggaccggaagtgagtcttgaggagcctgttgagggttagcagcgttggtt'
   'cccgactaaaggtcatgcctttgcttggcagttgtgctgggatgtctgtgtgagcaaggg'
   'agagcaacctgattgtcacccaaaatgtgtgcagatctgataacatttctggaacaagcc'
   'cctggagttctctgtgttagttctcctaatacccagccatcttgtcaggccagcactggg'
   'aactaaaataaaaaaaaaaaaagaagaggaagaagaagaagaagaagaagaagaagaaga'
   'agaagaagaaggagaaggagaaggagaaggagaaggagaaggagaaggagaaggagaagg'
   'agaaggagaaggagaaggagaaggagaagaagaagaagacagagaggaaagggacaggct'
   'tttctcttggtacagggctgcactgaatttgggtggctttttgagtataatgggatcgtg'
   'cagccatgactgcaagacacacttatgggcctgtgaaggggctaatcaatagggacctca'
   'ctgaacccaggactagttaaaggtaacatatgtggtacacaccagtttggagatgactga'
   'aaagagaggaagaaagaagaggaaagggcagcttggaagagcaggaagcagggtcctcag'
   'gctgctgaggcaaggactcctctgtggggagtgctgtgtctgctgttggttcaagtgagt'
   'ctctgggaggggatggtgtcctggttaggatttctattgctgtgatgaaacaccatgacc'
   'aagaacagattagggagaaagtatttatttggcttacaccatcatatcatgatccattgt'
   'tgaaggcagtcaggacaggaactcaagcagggcaggaacctaaatgcaggagctgatgca'
   'gaggccaccaaggggtgcttcttactggcttgccccatgtggcttgctcacctgggtttc'
   'ttatagaacccaggacaatgagcccagggttgaccctccccacaatgggctgggacctcc'
   'cccatcaatcactacttaagaaaataccctatgctgaaggcttgcctcagcctgatctca'
   'tggaagcattttctcaattgaggttcccatctctgaaatgattccagcctaggtcaaact'
   'gacacaaaactaggtagcacagaggggaacaagaagagtgtggaacacgtctgtgccctt'
   'gagctgtgcagggtaggacttctttgtagggcacacgaaggctcctttggtgagggtgct'
   'ctcttgaggttggggttagaatgcagatgggatatagctccaagcaggaacagctctggc'
   'atgtgtgatagtgaagggctgaagtgtggaatggaacaatttctgaagggagacatgggc'
   'agtgagcctctgggggactcatactgtggaactttgaaggcctggaaagaagacatttta'
   'ataggaagcttctcagagctgaggtgtgagtcagccctgtcacagggagtgaggaatccc'
   'tggtggctggggccggtgcccctggatggagaaccacagagactgccttgagaggcccca'
   'ctaggctgggggaaagcagaaactgggtggtaaccataggaagacagtttcccctgttct'
   'agtagtgaatggtgtggttgactcttcttgttgcaggctccctgggaccaagctgtagat'
   'attaattttaagacctctttgattactttgtagcacctgggctgtcccccatccagacag'
   'tgaaggtctctgtgtctgcagccaccctgggcctgggcttcatcatcttctgtgttggct'
   'tcttcagatggcgcaagtctcattcctccagtgagtgatctcctaaacattctgcagtcc'
   'tccctggtcctcctctttctcccagtctctcttgctttctgtctgaagtttattctctca'
   'tttgaacttgcaacttctgtggtgaggaacctccttcatccacaggggctggaataatga'
   'tgtctcttcctcttctaggctacactcctctctctggatccacctacccggaaggtaaca'
   'tttgtcttgggctttgtgctcagtcgtcctcgggaggggtggggtatatgttcataatat'
   'tgcttgcttatgataagcagcttatagcctgtttaggtaggctggaggtagctcctttgt'
   'cttggtcattggttgctgggcatttgttttgcattaccggtgtctgtgggctctggtgct'
   'gggtggtcatggacccaggtggtcgggtgtgttgaagcactatgtattctcactgcctga'
   'ttctggttgcttctgcaggacagcattagagagcagaacccggaaccaaggagattcaga'
   'ctcctgaggattccttaatgccccaacatcttcaggacaccccactttcttgtgtcatac'
   'tgcctctattcaggtccccttcctgaaataaatattagtagtttgggggggtatttataa'
   'tgaagtctgtcccaggtgggggagctgaggtgagctgaaatgaggtgggggttcaaggcc'
   'tcctgagagcccctccttgtcacgagggcaccgtgtcttaggtgatcactaagaaataaa'
   'ctggtggacttttgatttc'
);
INSERT INTO genomic_sequence VALUES ( 'H2-DMb2', 'NT_039662.1[394134..400213]', 6080,
   'ggttgagtgagtgggtacaaaggaggggctgagtgactcggggccacataggcagcaagg'
   'agcaaggggcctgagcaagaggtaccatatttacctcagtgtgtgaagatcatttgccca'
   'ggctggggcaggagagaacctgaggcccttgcaggaggtgcccaggggcctggccttcct'
   'gcaccttcagagagtggaacatggctgcactctggctgctgctgctggtcctcagtctgc'
   'actgtatgggggcaggtaagataacctcctgaaccttctctctcctgctcctgtttgggt'
   'aaaacatgttcatttttgctagctaacaggtctgagtgccccagagtagccagtctccag'
   'actatggcattcctccagccctgtgcactgtattttacagcaattttaataatgagccat'
   'tctcatagactgtgtgaaggatgtccctgtggggacgtaggttaggactgggtactgctg'
   'ggtcctggttcctaacatggtgcctggcatgacataagtgttctgtggtatcaaagtcaa'
   'gaatatttccagcacagagcaagactgactacttcttgactctgtttctttctctcctgt'
   'ccccttccctcctcctgttggtctgtttgtctgtctgtctatctatctgtctgactgtag'
   'tctgtctgtttctttctcattggagacagtcacgctctatagccagacttgccttaaact'
   'catggcaatcctcctgcctcagtgctgggatcacaagtatgccaaccacattactctatg'
   'tccctgtcaatagtgaggtgctctgcaggtctgttttggggtagacagccatgcatgcca'
   'cacaggaatcttgggttgtcctcccttgtcatccagtctcacatacagaagcgctaattg'
   'ttttcagccttgtgcacatgagcctcaagctcgtcccaaacctatgccctgccagatgtg'
   'gaagtctatcacaccatatgattttggtagaagagtggaattagcttgaaaatgcctttt'
   'ctgagttttgtttggttggctgttgttaggaaagccgggtatactaagttatttaaattt'
   'gttaccttaagaccttagaccactgcaggtggaaagcaacagcctgatttagtgtcagag'
   'ccttggggaggtggctcagcaatgaagagaactgggtgactctgctgaggacccaggttc'
   'aattcccagcactcacatcaagcacaagagggaagccccaggattaccgcgacttctgcc'
   'cagcttggctgagttagagccccttggcttggaaaatggagaaggcacagcgtctgtgca'
   'aatagaccgttattgttcatttactgcaagagtttaaaaacatttctctctcctgcttct'
   'ctgtttctgtctgtctgtatttctttgcctatctccctgtctctgtctcttgtctctctc'
   'tttctctttctgtctctctatctctgtctctatctgtgtgtgtgtgtgtgtgtgtgtgtg'
   'catgagcgtgtgtgcactctcatccgtgcttgtctgtgtgtgcaccacatctatgtagtg'
   'tctgatgaggccaaaagggtctcagactctctggaactggggatagagggagccattggg'
   'ggtaggtgctgtagttggaaacctcaacttctgcaagcaacatatacgtttaacatccag'
   'ccacatctctaacaccatgaggaatattttaaagaacaaagggttcataggaagacagcc'
   'aggcagagctcaggtgcagtagcttctgcccccaaaaggtaggtgtgccgatccccacca'
   'tatgaatgtgttcaccgactgggaaggtctcaggaccccacaacctgagatctttaggct'
   'tcatcaagtagacaggattttttttttttttttttttttttttttttttttttggttttt'
   'cgagacagggtttctctgtgtagccctggctgtcctggtactcactttgtagaccaggtt'
   'ggcctcgaactcagaaatccgcctgcctctgcctccggggtgctgggattaaaggcgtgc'
   'gccaccacacctggctgacaggatttatttttaatccagtctccagtcccctccctgctg'
   'ctccagatttgagatttaagtctcaggctcctaaagatggctccatctttccactgaaag'
   'gccccaccccagggttctgccaaaattgacctcattagaacaagggactccatggtcact'
   'cagtttcaagggtttcagagctctgggtgaggaaccaagtaaaagactagatattagggc'
   'agaaaatgcatctactcccctccccccaccataattagttataagggttttaggaacttt'
   'gtgttaggatctatgaatgggcagaggccatctttgcaatcctgccatgcagactctgac'
   'ttgccttccttcctttctgtgacatcttcccccaggtggctttgtggctcatgtggaaag'
   'cacgtgcgtgctgaatgatgctgggaccccacaggacttcacatactgtgtttccttcaa'
   'caaagatctgctggcctgctgggatccagatgtgggaaaaatagtcccctgtgaatttgg'
   'ggtgctgtctagattggctgaaataatttcaaatatcctcaacgaacaggagagccttat'
   'tcatcgcttgcaaaacgggcttcaggactgtgccacccacacccaacctttctgggatgt'
   'gctgacccacagaacgagtgagcagaggggcagtctgggagcacagccaggagggcagag'
   'gacaaggagatgcgtgagcaacaaaggggttgatacctgggcaggaagagacagtgtgga'
   'cctggaagaggcagcaggacatggagggagcagtgtggtaatggggtcggactggaggaa'
   'gaggatgtagtgagaaggaattgatgaggaccagaagcagaagccaaacatgtcagaagc'
   'cagaagtccaccaatgactttccccattcctgtctcttctttttatttattttaattaga'
   'tatttcttcccattactggggactgaactcaggaccctgcacatgcccggcaagcacttt'
   'accagtgtgtatgtcctaggtccatttctactatgtgttctgaggcaggatttcccaaag'
   'ttgccaaagctggctttgaacttgtaactcttgtttgggttgcagtcaactaggatcaca'
   'ggtttgggtccccagcctggcttatccttgtattttttgctcagattttgctgtttcata'
   'tttagaagtaatcccctttcaatgtgtggctgcagacagttttgaaaggatgaaatgaga'
   'cttccttaccaaccataactgcttctcccatgcaggagcgccatctgtccgagtagccca'
   'aaccacaccttttaacacaagggagcccgtgatgctggcctgctacgtctggggcttcta'
   'tccagcggatgtgaccatcacatggatgaagaatgggcagcttgtcccttcccacagcaa'
   'caaggagaagacggctcagcccaatggagactggacataccagacagtctcctacctagc'
   'cctaaccccttcctacggggacgtctacacctgcgtggttcagcacagcgggacctctga'
   'gcccatccgcggggactggagtaagtgtgtgggaactcggactttggtggttgggaaggg'
   'acatggatattttggctgaggtagtgagacgtgcaccggtgcgtggtccatgtaagagaa'
   'ggggatgctgggaccggaagtgagtctggaggagcctgttaagggttagcagtgttggtt'
   'cccgactaaaggtcatgcctttgcttggcagttgtgctgggatgtctgtgtgagcaaggg'
   'agagcaacctgattgtcacccaaaatgtgtgcagatttgataacatttctggaacaagtt'
   'ctctgtgttagttctcctaatacctagccatcttgtcaggccagatctagtaattgagaa'
   'aataaagtagacagaagaggaaaggggcaggctttcctcttggtacggggctgcactgaa'
   'tttgggtggctttttgagtataatgggatcgtgcagccatgactgcaagacacacttatg'
   'ggcctgtgaaggggcttatcaatagggacctcactgaacccaggactagttaaaggtaac'
   'atatgtggtacacaccagtttggaaatgactgaaaagagaggaagaaagaagaggaaagg'
   'gcagcttggaagagcaggaagcagggtcctcaggctgctgaggcaaggactcctctgtgg'
   'ggagtgctgtgtctgctgttggttctagtgagtctctgggaggggatggtgtcctggtta'
   'ggatttctattgctgtgatgaaacaccatgaccaggaacagactagggagaaagtattta'
   'tttggcttacaccatcacatcatgatccattgttgaaggcagtcaggacaggaactcaag'
   'cagggcaggaacctaaatgcaggagctgatgcagaggccaccaaggggtgcttcttactg'
   'gcttgccccatgtggcttgctcacctgggtttcttgtagaactcaggaccatgaacccat'
   'gggtggccctccccacaatgggctgggacctcccccatcaatcactacttaagaaaatac'
   'cctatgctgaaggcttgcctcagcctgacctcatggaagcattttctcaattgaggttcc'
   'catctctgaaatgattccagcctaggtcaaactgacacaaaactaggtagcacagagggg'
   'aacaagaagagtgtggaacacgtctgtgcccttgagctgtgcagggtaggactcctttgt'
   'agggcacacgaggggggctcctttggtgagggagctctcttgatgttggggttagaatgc'
   'agatgggatatagctccaagcaggaacagctctggcatgtgggatagtgaagggctgaag'
   'tgtggaatggaagcaaattctgaaagaagacacgggcagtgaggctctgggggactcata'
   'ctgtggaactttgagggcctggaaagaagacattttaataggaagctgttcagagctgag'
   'gtgtgagtcagccctgccacagggagtgaggaatccctggtggctggggccagtgcccct'
   'ggatggagaaccacagagactgccttgagaggccccactaggctgggggaaaacagaaac'
   'tgggtggtaaccataggaagacagtttcccctgttctagtagtgaatggtgtggttgact'
   'cttcttgttgcaggctccctgggaccaagctgtagatattaattttaagacctctttgat'
   'tactttgtagcacctgggctgtcccccatccagacagtgaaggtctctgtgtctgcagcc'
   'accctgggcctgggcttcatcatcttctgtgttggcttcttcagatggcgcaagtctcat'
   'tcctccagtgagtgatcccctgaacattctgcagtcctccctggtcctcctctttctccc'
   'agtctctcttgctttctgtctgggttgattctctcatttgaactcccaacttctgtggtg'
   'aggaacctccttcatccacaggggctggaataatgatgtctcttcttcttctaggctaca'
   'ctcctctccccggatccacctacccagaaggtaacatttgtcttgggctttgtgctcagt'
   'cgtcctcgggaggggtagggtatatgttcataatattgcttgcttatgataagcagctta'
   'tagcctgtttaggtaggctggaggtagctcctttgtcttggtcattggttgctgggcatt'
   'tgttttgcattaccagtgtttgtggtctctggtgctgggtggttatggacacaggtggtc'
   'gggtgttttgcagaccattctcactgcctgattctggttgcttctgcaggacggcactag'
   'aaagcagaacccagaaccaaggagattcagactcctgaggattccttcatgcccccaata'
   'tcttcaggacaccccattttcttgtgtcatactgcctctattcagtttcccttcccaatg'
   'taattttttttttgttttttgtttttttgagacagggtttctctgtatagccctggctgt'
   'cctggaactcactttgtaga'
);



-------------------------------------------------------------------------
-- The following queries need updating for the relations above
-------------------------------------------------------------------------
-- 
-- find all exons in isoforms that code for specific protein features

CREATE TABLE exon_feature
AS
SELECT DISTINCT
   e.gene,
   e.exon_no,
   f.protein_id,
   f.interval,
   f.type,
   f.description
FROM
   gene g,
   exon e,
   mrna m,
   protein p,
   protein_feature f
WHERE
   e.gene = g.gene
   AND e.gene = m.gene
   AND e.gene = p.gene
   AND p.protein_id = f.protein_id
   AND loc_range(e.coding_mrna) - range_lower(loc_range(m.coding_mrna))
         + '-2..2'::range     -- mrna segment extended for reading frame
       @                      -- contains feature interval:
       (f.interval - 1) * 3
ORDER BY e.gene, e.exon_no
;

-- for any given pair of isoforms, find common exons

CREATE TABLE isoform_shared_exon
AS
SELECT
   i1.isoform_id as isoform1,
   i2.isoform_id as isoform2,
   i1.gene,
   i1.exon_no
FROM
   isoform_exon i1,
   isoform_exon i2
WHERE
   i1.gene = i2.gene
   AND i1.exon_no = i2.exon_no
   AND i1.isoform_id < i2.isoform_id
ORDER BY i1.isoform_id, i2.isoform_id
;

-- find all exons that are possessed by only one isoform

CREATE TABLE unique_isoform_exon
AS
SELECT
   i.gene,
   i.exon_no,
   i.isoform_id
FROM
   isoform_exon i
WHERE
   i.exon_no NOT IN
     -- the set of shared exons
      (SELECT exon_no
      FROM isoform_shared_exon s
      WHERE s.isoform1 = i.isoform_id
         OR s.isoform2 = i.isoform_id)
;

-- for any pair of distinct isoforms, find the number of common exons
CREATE TABLE number_of_isoform_shared_exons
AS
SELECT
   isoform1,
   isoform2,
   gene,
   count(exon_no) as shared_exons
FROM
   isoform_shared_exon
GROUP BY isoform1, isoform2, gene
;


-- find counts of the number of times each exon is shared
CREATE TABLE isoform_exon_sharing
AS
SELECT
   gene,
   exon_no,
   count(*)
FROM
   isoform_shared_exon
GROUP BY gene, exon_no;

-- find overlaps between exons and splices

CREATE TABLE splice_exon_overlap
AS
SELECT DISTINCT
   e.gene,
   s.splice_no,
   s.genomic_interval as splice_interval,
   e.exon_no,
   e.genomic_interval as exon_interval,
   range_inter(e.genomic_interval,s.genomic_interval) as overlap
FROM
   exon e,
   splice s
WHERE
   e.gene = s.gene
   AND e.genomic_interval && s.genomic_interval -- range overlap
;

-- find all splices that remove a specific exon-coded protein feature

CREATE TABLE exon_feature_removing_splice
AS
SELECT
   seo.gene,
   seo.splice_no,
   seo.splice_interval,
   ef.exon_no,
   ef.protein_id,
   ef.interval,
   ef.type,
   ef.description
FROM
   splice_exon_overlap seo,
   exon_feature ef
WHERE
   seo.gene = ef.gene
----ORDER BY s.splice_no
;


-- find alternative splicing

CREATE TABLE alternative_splicing
AS
SELECT DISTINCT
   s1.gene,
   s1.splice_no as splice_no1,
   s1.genomic_interval as genomic1,
   upper(substr(s1._5prime_site,11,2)||'/'||substr(s1._3prime_site,9,2)) as type1,
   s2.splice_no as splice_no2,
   s2.genomic_interval as genomic2,
   upper(substr(s2._5prime_site,11,2)||'/'||substr(s2._3prime_site,9,2)) as type2,
   range_size(range_inter(s1.genomic_interval,s2.genomic_interval)) as overlap,
   CASE
      WHEN  range_started_by(s1.genomic_interval,s2.genomic_interval) THEN 'same 5\''
      WHEN range_finished_by(s1.genomic_interval,s2.genomic_interval) THEN 'same 3\''
   END as kind
FROM
   splice s1,
   splice s2
WHERE
   s1.gene = s2.gene
   AND s1.splice_no <> s2.splice_no
      AND ( range_started_by(s1.genomic_interval,s2.genomic_interval)
        OR range_finished_by(s1.genomic_interval,s2.genomic_interval) )
;


-- find all genes that are alternatively spliced.

CREATE TABLE alternatively_spliced_genes
AS
SELECT
   gene,
   count(isoform_id) as number_of_alternative_splice_forms
FROM
   isoform
WHERE
   gene IN (SELECT DISTINCT gene FROM alternative_splicing)
GROUP BY gene;



-- find all pairs of orthologous genes that are
-- alternatively spliced in one organism,
-- but not the other.

CREATE TABLE nonconserved_alternative_splicing
AS
SELECT DISTINCT
   alt_spliced.gene as alt_spliced,
   non_alt_spliced.gene as non_alt_spliced
FROM
   gene_ortholog go,
   gene non_alt_spliced,
   alternative_splicing alt_spliced
WHERE
   ((go.gene = alt_spliced.gene 
      AND go.ortholog = non_alt_spliced.gene)
    OR (go.gene = non_alt_spliced.gene
      AND go.ortholog = alt_spliced.gene))
   AND non_alt_spliced.gene NOT IN
          (SELECT DISTINCT gene 
           FROM alternative_splicing)
;


-- find all genes that have more than one ortholog

CREATE TABLE genes_with_multiple_orthologs
AS
SELECT
   g.gene,
   g1.gene as ortholog1,
   g2.gene as ortholog2
FROM
   gene g,
   gene g1,
   gene g2,
   gene_ortholog o1,
   gene_ortholog o2
WHERE
   ((g.gene = o1.gene AND g.gene = o2.gene
        AND g1.gene = o1.ortholog AND g2.gene = o2.ortholog)
    OR (g.gene = o1.ortholog AND g.gene = o2.ortholog
        AND g1.gene = o1.gene AND g2.gene = o2.gene))
   AND (g1.gene < g2.gene)
ORDER BY g.gene
;

-- find differences in protein features for pairs of orthologous genes

CREATE TABLE orthologous_gene_protein_feature_differences
AS
SELECT
   go.gene,
   go.ortholog,
   -- g1.gene as gene_with_differences,
   p.protein_id,
   p.interval,
   p.type,
   p.description
FROM
   gene g1,
   gene g2,
   protein_feature p,
   gene_ortholog go
WHERE
   g1.protein_id = p.protein_id
   AND ((g1.gene = go.gene AND g2.gene = go.ortholog) OR (g2.gene = go.gene AND g1.gene = go.ortholog))
   AND ((p.type NOT IN (SELECT type from protein_feature WHERE protein_id=g2.protein_id))
        OR (p.interval NOT IN (SELECT interval from protein_feature WHERE protein_id=g2.protein_id))
        OR (p.description NOT IN (SELECT description from protein_feature WHERE protein_id=g2.protein_id))
       )
ORDER BY go.gene, go.ortholog
;



CREATE TABLE pairwise_orthologous_gene_protein_feature_differences
AS
SELECT
   g.gene         as gene1,
   go.ortholog    as gene2,
   gp.protein_id  as protein1,
   op.protein_id  as protein2,
   gp.interval    as interval1,
   op.interval    as interval2,
   gp.description as description1,
   op.description as description2
FROM
   gene g,
   gene o,
   gene_ortholog go,
   protein_feature gp,
   protein_feature op
WHERE
   g.gene = go.gene
   AND o.gene = go.ortholog
   AND g.protein_id = gp.protein_id
   AND o.protein_id = op.protein_id
   AND (
       ((gp.description<>op.description) AND (gp.interval= op.interval) AND (gp.type=op.type))
       OR
       ((gp.description= op.description) AND (gp.interval<>op.interval) AND (gp.type=op.type))
   )
ORDER BY g.gene, go.ortholog
;



-- find alternatively_spliced exons

CREATE TABLE alternatively_spliced_exon
AS
SELECT DISTINCT
     e.gene,
     e.exon_no as alternatively_spliced_exon,
     e.isoform_id
FROM
     isoform_exon e
WHERE EXISTS -- another isoform that lacks the exon e.exon_no
          (SELECT * FROM isoform_exon other
           WHERE e.isoform_id <> other.isoform_id AND other.gene = e.gene
             AND NOT EXISTS
                   (SELECT * FROM isoform_exon
                    WHERE isoform_id = other.isoform_id AND gene = e.gene
                      AND exon_no = e.exon_no))
;


-- find stopless peptide exons

CREATE TABLE stopless_peptide_exon
AS
SELECT DISTINCT
   e.gene,
   e.exon_no,
   int4(range_size(coding_interval)) as exon_length
FROM
   exon e,
   genomic_sequence gs
WHERE
   e.gene = gs.gene
   AND (range_size(e.coding_interval) % 3) = 0
   AND substr(gs.seq,int4(range_lower(e.coding_interval)),
                     int4(range_size( e.coding_interval)) ) !~* '(taa|tag|tga)'
      -- there is no stop codon sequence in the exon sequence
;

-- find peptide exons

CREATE TABLE peptide_exon
AS
SELECT DISTINCT
   e.gene,
   e.exon_no,
   int4(range_size(coding_interval)) as exon_length
FROM
   exon e,
   genomic_sequence gs
WHERE
   e.gene = gs.gene
   AND (range_size(e.coding_interval) % 3) = 0
   AND substr(gs.seq,int4(range_lower(e.coding_interval)),
                     int4(range_size( e.coding_interval)) ) !~* '^(...)*(taa|tag|tga)'
      -- there is no (in frame) stop codon in the exon sequence
;

-- find stopless peptide alternatively_spliced exons

CREATE TABLE stopless_peptide_alternatively_spliced_exon
AS
SELECT DISTINCT
   e.gene,
   e.exon_no,
   e.exon_length
FROM
   stopless_peptide_exon e
WHERE
   EXISTS
     (SELECT * from alternatively_spliced_exon WHERE  gene=e.gene AND exon_no=e.exon_no)
;


CREATE TABLE splice_site
AS
(SELECT DISTINCT
   gene,
   range_torange(range_lower(genomic_interval)-10,range_lower(genomic_interval)-1) as start_interval,
   range_torange(range_lower(genomic_interval),   range_lower(genomic_interval)+9) as end_interval,
   substr(_5prime_site,1,10) as start,
   substr(_5prime_site,11,10) as end
FROM
   splice)
UNION
(SELECT DISTINCT
   gene,
   range_torange(range_upper(genomic_interval)-9,range_upper(genomic_interval)) as start_interval,
   range_torange(range_upper(genomic_interval)+1,range_upper(genomic_interval)+10) as end_interval,
   substr(_3prime_site,1,10) as start,
   substr(_3prime_site,11,10) as end
FROM
   splice)
;

----------------------------------------------

       \qecho gene 
SELECT * FROM gene ;
       \qecho gene_ortholog 
SELECT * FROM gene_ortholog ;
       \qecho splice 
SELECT * FROM splice ;
       \qecho exon 
SELECT * FROM exon ;
       \qecho isoform 
SELECT * FROM isoform ;
       \qecho protein 
SELECT * FROM protein ;
       \qecho protein_feature 
SELECT * FROM protein_feature ;

       \qecho exon_exon 
SELECT * FROM exon_exon ;
       \qecho isoform_exon 
SELECT * FROM isoform_exon ;

--        \qecho protein_sequence 
-- SELECT * FROM protein_sequence ;
--        \qecho mrna_sequence 
-- SELECT * FROM mrna_sequence ;
--        \qecho genomic_sequence 
-- SELECT * FROM genomic_sequence ;

       \qecho exon_feature
SELECT * FROM exon_feature ;
       \qecho isoform_shared_exon 
SELECT * FROM isoform_shared_exon ;
       \qecho unique_isoform_exon 
SELECT * FROM unique_isoform_exon ;
       \qecho number_of_isoform_shared_exons 
SELECT * FROM number_of_isoform_shared_exons ;
       \qecho isoform_exon_sharing 
SELECT * FROM isoform_exon_sharing ;

       \qecho splice_exon_overlap 
SELECT * FROM splice_exon_overlap ;
       \qecho alternative_splicing 
SELECT * FROM alternative_splicing ;
       \qecho exon_feature_removing_splice
SELECT * FROM exon_feature_removing_splice ;
       \qecho alternatively_spliced_genes
SELECT * FROM alternatively_spliced_genes ;
       \qecho nonconserved_alternative_splicing
SELECT * FROM nonconserved_alternative_splicing ;

       \qecho genes_with_multiple_orthologs
SELECT * FROM genes_with_multiple_orthologs ;
       \qecho orthologous_gene_protein_feature_differences
SELECT * FROM orthologous_gene_protein_feature_differences ;
       \qecho pairwise_orthologous_gene_protein_feature_differences
SELECT * FROM pairwise_orthologous_gene_protein_feature_differences ;

       \qecho alternatively_spliced_exon
SELECT * FROM alternatively_spliced_exon ;
       \qecho stopless_peptide_exon
SELECT * FROM stopless_peptide_exon ;
       \qecho peptide_exon
SELECT * FROM peptide_exon ;
       \qecho stopless_peptide_alternatively_spliced_exon
SELECT * FROM stopless_peptide_alternatively_spliced_exon ;

;

----------------------------------------------

       \qecho gene 
SELECT * FROM gene ;
       \qecho gene_ortholog 
SELECT * FROM gene_ortholog ;
       \qecho splice 
SELECT * FROM splice ;
       \qecho exon 
SELECT * FROM exon ;
       \qecho isoform 
SELECT * FROM isoform ;
       \qecho protein 
SELECT * FROM protein ;
       \qecho protein_feature 
SELECT * FROM protein_feature ;

       \qecho exon_exon 
SELECT * FROM exon_exon ;
       \qecho isoform_exon 
SELECT * FROM isoform_exon ;

--        \qecho protein_sequence 
-- SELECT * FROM protein_sequence ;
--        \qecho mrna_sequence 
-- SELECT * FROM mrna_sequence ;
--        \qecho genomic_sequence 
-- SELECT * FROM genomic_sequence ;

       \qecho exon_feature
SELECT * FROM exon_feature ;
       \qecho isoform_shared_exon 
SELECT * FROM isoform_shared_exon ;
       \qecho unique_isoform_exon 
SELECT * FROM unique_isoform_exon ;
       \qecho number_of_isoform_shared_exons 
SELECT * FROM number_of_isoform_shared_exons ;
       \qecho isoform_exon_sharing 
SELECT * FROM isoform_exon_sharing ;

       \qecho splice_exon_overlap 
SELECT * FROM splice_exon_overlap ;
       \qecho alternative_splicing 
SELECT * FROM alternative_splicing ;
       \qecho exon_feature_removing_splice
SELECT * FROM exon_feature_removing_splice ;
       \qecho alternatively_spliced_genes
SELECT * FROM alternatively_spliced_genes ;
       \qecho nonconserved_alternative_splicing
SELECT * FROM nonconserved_alternative_splicing ;

       \qecho genes_with_multiple_orthologs
SELECT * FROM genes_with_multiple_orthologs ;
       \qecho orthologous_gene_protein_feature_differences
SELECT * FROM orthologous_gene_protein_feature_differences ;
       \qecho pairwise_orthologous_gene_protein_feature_differences
SELECT * FROM pairwise_orthologous_gene_protein_feature_differences ;

       \qecho alternatively_spliced_exon
SELECT * FROM alternatively_spliced_exon ;
       \qecho stopless_peptide_exon
SELECT * FROM stopless_peptide_exon ;
       \qecho peptide_exon
SELECT * FROM peptide_exon ;
       \qecho stopless_peptide_alternatively_spliced_exon
SELECT * FROM stopless_peptide_alternatively_spliced_exon ;

       \qecho splice_site
SELECT * FROM splice_site ;

