/*
**    BLASTgres -- Biosequence data management in PostgreSQL
**    http://www.blastgres.org/
**
**    Copyright (C) 2005, 2006  Ruey-Lung Hsiao,  D.S. Parker
**    (rlhsiao@cs.ucla.edu, stott@cs.ucla.edu)
**
**    UCLA Center for Computational Biology
**    635 Charles Young Drive South, Suite 225
**    Los Angeles, CA 90095-7332  USA
**
**    UCLA Computer Science Dept.
**    3532 Boelter Hall
**    Los Angeles, CA 90095-1596  USA
**
**    This program is free software; you can redistribute it and/or
**    modify it under the terms of the GNU General Public License
**    as published by the Free Software Foundation; either version 2 of
**    the License, or (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
**    See the GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public
**    License along with this program; if not, write to the
**    Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
**    Boston, MA  02110-1301  USA
*/

/*-------------------------------------------------------------------------
 *
 * blast.h
 *
 *    Definitions of functions for BLAST-related table functions.
 *
 * This file is included in blast.c and all other files which request
 * BLAST table functions in Postgresql.
 *
 * This is part of the BLASTgres project.
 *
 *-------------------------------------------------------------------------
 */

#ifndef BLAST_H
#define BLAST_H

#include "blastsvc.h"

#define HIT_TABLE_TYPE_NAME     "hit"
#define HSP_TYPE_NAME           "hsp"
#define MEGABLAST_TYPE_NAME     "megablast_hit"

/* exported functions */
//extern Datum blast_sequence(PG_FUNCTION_ARGS);
//extern Datum blast_sequence_v(PG_FUNCTION_ARGS);
extern Datum local_blast_sequence(PG_FUNCTION_ARGS);
extern Datum fasta_sequence(PG_FUNCTION_ARGS);
extern Datum fasta_dbinfo(PG_FUNCTION_ARGS);


extern Datum remote_blast_hit(PG_FUNCTION_ARGS);
extern Datum remote_blast_hsp(PG_FUNCTION_ARGS);
extern Datum local_blast_hit(PG_FUNCTION_ARGS);
extern Datum local_blast_hsp(PG_FUNCTION_ARGS);

extern Datum local_blast_hit_v(PG_FUNCTION_ARGS);
extern Datum local_blast_hsp_v(PG_FUNCTION_ARGS);
extern Datum remote_blast_hit_v(PG_FUNCTION_ARGS);
extern Datum remote_blast_hsp_v(PG_FUNCTION_ARGS);
extern Datum local_megablast(PG_FUNCTION_ARGS);


/* this structure is used to save the memory context between each
   Postgresql call to table function. 
   -  processed points to the next hit table record we are about to 
      process.
   -  hittable points to the whole hit table data returned from 
      BLAST service.
*/


/* functions used internally */
Datum HitTableFormTuple( HitTableEntryPointer, TupleTableSlot *, AttInMetadata *);
Datum HspFormTuple( HspEntryPointer, TupleTableSlot *, AttInMetadata *);
Datum MegaBlastFormTuple(MegaBlastEntryPointer, TupleTableSlot *, AttInMetadata *);

/* internal helper functions */
//int is_filename( char *str );
int isSequenceFile( char *str);
//char* read_seq_from_file( char *filename );
char* RemoteBlastService(char *sequence, char *program, char *db, int type);
char* RemoteBlastService_V(char *sequence, char **parameters, int type) ;

#endif   /* BLAST_H */
